@@ -1,20 +1,23 @@
 #
-# Copyright (c) 2008-2010 by FlashCode <flashcode@flashtux.org>
+# Copyright (C) 2008-2010 Sebastien Helleu <flashcode@flashtux.org>
 #
-# This program is free software; you can redistribute it and/or modify
+# This file is part of WeeChat, the extensible chat client.
+#
+# WeeChat is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# WeeChat is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+#
 # Documentation generator for WeeChat: build include files with commands,
 # options, infos and completions for WeeChat core and plugins.
 #
@@ -28,8 +31,6 @@
 #           /docgen
 # Files should be in ~/src/weechat/doc/xx/autogen/ (where xx is language)
 #
-# Script written on 2008-08-22 by FlashCode <flashcode@flashtux.org>
-#
 
 use strict;
 
@@ -53,7 +54,7 @@ my $version = "0.1";
 my $default_path = "~/src/weechat/doc";
 
 # list of locales for which we want to build XML doc files to include
-my @all_locale_list = qw(en_US fr_FR it_IT);
+my @all_locale_list = qw(en_US fr_FR it_IT de_DE);
 
 # all commands/options/.. of following plugins will produce a file
 # non-listed plugins will be ignored
@@ -105,7 +106,7 @@ my $d;
 
 # -------------------------------[ init ]--------------------------------------
 
-weechat::register("docgen", "FlashCode <flashcode\@flashtux.org>", $version,
+weechat::register("docgen", "Sebastien Helleu <flashcode\@flashtux.org>", $version,
                   "GPL3", "Doc generator for WeeChat 0.3.x", "", "");
 weechat::hook_command("docgen", "Doc generator",
                       "[locales]",
@@ -275,7 +276,7 @@ sub get_completions
             $ignore = 1 if ($completion_item =~ /${mask}/);
         }
         
-        if ($ignore ne 1)
+        if (($ignore ne 1) && ($completion_item ne ""))
         {
             $completions{$plugin}{$completion_item}{"description"} = weechat::infolist_string($infolist, "description");
         }
