@@ -1,26 +1,27 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * wee-config.c: WeeChat configuration options (file weechat.conf)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -71,11 +72,13 @@ struct t_config_option *config_startup_display_version;
 
 /* config, look & feel section */
 
+struct t_config_option *config_look_align_end_of_lines;
 struct t_config_option *config_look_buffer_notify_default;
 struct t_config_option *config_look_buffer_time_format;
 struct t_config_option *config_look_color_nicks_number;
 struct t_config_option *config_look_color_real_white;
 struct t_config_option *config_look_command_chars;
+struct t_config_option *config_look_confirm_quit;
 struct t_config_option *config_look_day_change;
 struct t_config_option *config_look_day_change_time_format;
 struct t_config_option *config_look_highlight;
@@ -86,6 +89,7 @@ struct t_config_option *config_look_hotlist_names_level;
 struct t_config_option *config_look_hotlist_names_merged_buffers;
 struct t_config_option *config_look_hotlist_short_names;
 struct t_config_option *config_look_hotlist_sort;
+struct t_config_option *config_look_input_undo_max;
 struct t_config_option *config_look_item_time_format;
 struct t_config_option *config_look_jump_current_to_previous_buffer;
 struct t_config_option *config_look_jump_previous_buffer_when_closing;
@@ -140,6 +144,7 @@ struct t_config_option *config_color_chat_text_found_bg;
 struct t_config_option *config_color_chat_value;
 struct t_config_option *config_color_status_number;
 struct t_config_option *config_color_status_name;
+struct t_config_option *config_color_status_name_ssl;
 struct t_config_option *config_color_status_filter;
 struct t_config_option *config_color_status_data_msg;
 struct t_config_option *config_color_status_data_private;
@@ -152,11 +157,6 @@ struct t_config_option *config_color_input_actions;
 struct t_config_option *config_color_nicklist_group;
 struct t_config_option *config_color_nicklist_away;
 struct t_config_option *config_color_nicklist_offline;
-struct t_config_option *config_color_nicklist_prefix1;
-struct t_config_option *config_color_nicklist_prefix2;
-struct t_config_option *config_color_nicklist_prefix3;
-struct t_config_option *config_color_nicklist_prefix4;
-struct t_config_option *config_color_nicklist_prefix5;
 
 /* config, completion section */
 
@@ -1234,6 +1234,13 @@ config_weechat_init_options ()
         return 0;
     }
     
+    config_look_align_end_of_lines = config_file_new_option (
+        weechat_config_file, ptr_section,
+        "align_end_of_lines", "integer",
+        N_("alignment for end of lines (all lines after the first): they "
+           "are starting under this data (time, buffer, prefix, suffix, "
+           "message (default))"),
+        "time|buffer|prefix|suffix|message", 0, 0, "message", NULL, 0, NULL, NULL, &config_change_buffers, NULL, NULL, NULL);
     config_look_buffer_notify_default = config_file_new_option (
         weechat_config_file, ptr_section,
         "buffer_notify_default", "integer",
@@ -1268,6 +1275,12 @@ config_weechat_init_options ()
            "input must start with one of these chars; the slash (\"/\") is "
            "always considered as command prefix (example: \".$\")"),
         NULL, 0, 0, "", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+    config_look_confirm_quit = config_file_new_option (
+        weechat_config_file, ptr_section,
+        "confirm_quit", "boolean",
+        N_("if set, /quit command must be confirmed with extra argument "
+           "\"-yes\" (see /help quit)"),
+        NULL, 0, 0, "off", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     config_look_day_change = config_file_new_option (
         weechat_config_file, ptr_section,
         "day_change", "boolean",
@@ -1329,6 +1342,12 @@ config_weechat_init_options ()
         "group_time_asc|group_time_desc|group_number_asc|"
         "group_number_desc|number_asc|number_desc",
         0, 0, "group_time_asc", NULL, 0, NULL, NULL, &config_change_hotlist, NULL, NULL, NULL);
+    config_look_input_undo_max = config_file_new_option (
+        weechat_config_file, ptr_section,
+        "input_undo_max", "integer",
+        N_("max number of \"undo\" for command line, by buffer (0 = undo "
+           "disabled)"),
+        NULL, 0, 65535, "32", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     config_look_item_time_format = config_file_new_option (
         weechat_config_file, ptr_section,
         "item_time_format", "string",
@@ -1739,6 +1758,13 @@ config_weechat_init_options ()
         N_("text color for current buffer name in status bar"),
         NULL, -1, 0, "white", NULL, 0,
         NULL, NULL, &config_change_color, NULL, NULL, NULL);
+    config_color_status_name_ssl = config_file_new_option (
+        weechat_config_file, ptr_section,
+        "status_name_ssl", "color",
+        N_("text color for current buffer name in status bar, if data are "
+           "secured with a protocol like SSL"),
+        NULL, -1, 0, "lightgreen", NULL, 0,
+        NULL, NULL, &config_change_color, NULL, NULL, NULL);
     config_color_status_filter = config_file_new_option (
         weechat_config_file, ptr_section,
         "status_filter", "color",
@@ -1814,36 +1840,6 @@ config_weechat_init_options ()
         N_("text color for offline nicknames"),
         NULL, -1, 0, "blue", NULL, 0,
         NULL, NULL, &config_change_color, NULL, NULL, NULL);
-    config_color_nicklist_prefix1 = config_file_new_option (
-        weechat_config_file, ptr_section,
-        "nicklist_prefix1", "color",
-        N_("text color for prefix #1 in nicklist"),
-        NULL, -1, 0, "lightgreen", NULL, 0,
-        NULL, NULL, &config_change_color, NULL, NULL, NULL);
-    config_color_nicklist_prefix2 = config_file_new_option (
-        weechat_config_file, ptr_section,
-        "nicklist_prefix2", "color",
-        N_("text color for prefix #2 in nicklist"),
-        NULL, -1, 0, "lightmagenta", NULL, 0,
-        NULL, NULL, &config_change_color, NULL, NULL, NULL);
-    config_color_nicklist_prefix3 = config_file_new_option (
-        weechat_config_file, ptr_section,
-        "nicklist_prefix3", "color",
-        N_("text color for prefix #3 in nicklist"),
-        NULL, -1, 0, "yellow", NULL, 0,
-        NULL, NULL, &config_change_color, NULL, NULL, NULL);
-    config_color_nicklist_prefix4 = config_file_new_option (
-        weechat_config_file, ptr_section,
-        "nicklist_prefix4", "color",
-        N_("text color for prefix #4 in nicklist"),
-        NULL, -1, 0, "blue", NULL, 0,
-        NULL, NULL, &config_change_color, NULL, NULL, NULL);
-    config_color_nicklist_prefix5 = config_file_new_option (
-        weechat_config_file, ptr_section,
-        "nicklist_prefix5", "color",
-        N_("text color for prefix #5 in nicklist"),
-        NULL, -1, 0, "brown", NULL, 0,
-        NULL, NULL, &config_change_color, NULL, NULL, NULL);
     
     /* completion */
     ptr_section = config_file_new_section (weechat_config_file, "completion",
