@@ -1,22 +1,23 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_CONFIG_H
 #define __WEECHAT_CONFIG_H 1
 
@@ -34,6 +35,15 @@ enum t_config_look_nicklist
     CONFIG_LOOK_NICKLIST_BOTTOM,
 };
 
+enum t_config_look_align_end_of_lines
+{
+    CONFIG_LOOK_ALIGN_END_OF_LINES_TIME = 0,
+    CONFIG_LOOK_ALIGN_END_OF_LINES_BUFFER,
+    CONFIG_LOOK_ALIGN_END_OF_LINES_PREFIX,
+    CONFIG_LOOK_ALIGN_END_OF_LINES_SUFFIX,
+    CONFIG_LOOK_ALIGN_END_OF_LINES_MESSAGE,
+};
+
 enum t_config_look_prefix_align
 {
     CONFIG_LOOK_PREFIX_ALIGN_NONE = 0,
@@ -84,9 +94,11 @@ extern struct t_config_option *config_startup_command_before_plugins;
 extern struct t_config_option *config_startup_display_logo;
 extern struct t_config_option *config_startup_display_version;
 
+extern struct t_config_option *config_look_align_end_of_lines;
 extern struct t_config_option *config_look_buffer_notify_default;
 extern struct t_config_option *config_look_buffer_time_format;
 extern struct t_config_option *config_look_command_chars;
+extern struct t_config_option *config_look_confirm_quit;
 extern struct t_config_option *config_look_color_nicks_number;
 extern struct t_config_option *config_look_color_real_white;
 extern struct t_config_option *config_look_day_change;
@@ -99,6 +111,7 @@ extern struct t_config_option *config_look_hotlist_names_level;
 extern struct t_config_option *config_look_hotlist_names_merged_buffers;
 extern struct t_config_option *config_look_hotlist_short_names;
 extern struct t_config_option *config_look_hotlist_sort;
+extern struct t_config_option *config_look_input_undo_max;
 extern struct t_config_option *config_look_item_time_format;
 extern struct t_config_option *config_look_jump_current_to_previous_buffer;
 extern struct t_config_option *config_look_jump_previous_buffer_when_closing;
@@ -151,6 +164,7 @@ extern struct t_config_option *config_color_chat_text_found_bg;
 extern struct t_config_option *config_color_chat_value;
 extern struct t_config_option *config_color_status_number;
 extern struct t_config_option *config_color_status_name;
+extern struct t_config_option *config_color_status_name_ssl;
 extern struct t_config_option *config_color_status_filter;
 extern struct t_config_option *config_color_status_data_msg;
 extern struct t_config_option *config_color_status_data_private;
@@ -163,11 +177,6 @@ extern struct t_config_option *config_color_input_actions;
 extern struct t_config_option *config_color_nicklist_group;
 extern struct t_config_option *config_color_nicklist_away;
 extern struct t_config_option *config_color_nicklist_offline;
-extern struct t_config_option *config_color_nicklist_prefix1;
-extern struct t_config_option *config_color_nicklist_prefix2;
-extern struct t_config_option *config_color_nicklist_prefix3;
-extern struct t_config_option *config_color_nicklist_prefix4;
-extern struct t_config_option *config_color_nicklist_prefix5;
 
 extern struct t_config_option *config_completion_default_template;
 extern struct t_config_option *config_completion_nick_add_space;
@@ -204,4 +213,4 @@ extern int config_weechat_init ();
 extern int config_weechat_read ();
 extern int config_weechat_write ();
 
-#endif /* wee-config.h */
+#endif /* __WEECHAT_CONFIG_H */
