@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * wee-string.c: string functions for WeeChat
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -395,6 +395,36 @@ string_replace (const char *string, const char *search, const char *replace)
     return new_string;
 }
 
+/*
+ * string_expand_home: expand home in a PATH
+ *                     (for example: "~/file.txt" => "/home/xxx/file.txt")
+ *                     note: returned value has to be free() after use
+ */
+
+char *
+string_expand_home (const char *path)
+{
+    char *ptr_home, *str;
+    int length;
+    
+    if (!path)
+        return NULL;
+    
+    if (!path[0] || (path[0] != '~') || (path[1] != DIR_SEPARATOR_CHAR))
+        return strdup (path);
+    
+    ptr_home = getenv ("HOME");
+    
+    length = strlen (ptr_home) + strlen (path + 1) + 1;
+    str = malloc (length);
+    if (!str)
+        return strdup (path);
+    
+    snprintf (str, length, "%s%s", ptr_home, path + 1);
+    
+    return str;
+}
+
 /*
  * string_remove_quotes: remove quotes at beginning/end of string
  *                       (ignore spaces if there are before first quote or
@@ -680,7 +710,7 @@ string_has_highlight (const char *string, const char *highlight_words)
 }
 
 /*
- * string_mask_to_regex: convert a mask (string with only "*" as joker) to a
+ * string_mask_to_regex: convert a mask (string with only "*" as wildcard) to a
  *                       regex, paying attention to special chars in a regex
  */
 
