@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * wee-util.c: some useful functions for WeeChat
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -417,6 +417,7 @@ util_file_get_content (const char *filename)
  *                      (non-digit chars like "-dev" are ignored)
  *                      for example:
  *                        "0.3.2-dev" ==> 197120 (== 0x00030200)
+ *                        "0.3.2-rc1" ==> 197120 (== 0x00030200)
  *                        "0.3.2"     ==> 197120 (== 0x00030200)
  *                        "0.3.1.1"   ==> 196865 (== 0x00030101)
  *                        "0.3.1"     ==> 196864 (== 0x00030100)
@@ -440,6 +441,8 @@ util_version_number (const char *version)
             index_buf = 0;
             while (ptr_item && ptr_item[0] && (index_buf < (int)sizeof (buf) - 1))
             {
+                if (ptr_item[0] == '-')
+                    break;
                 if (isdigit (ptr_item[0]))
                 {
                     buf[index_buf] = ptr_item[0];
