@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-curses-bar-window.c: bar window functions for Curses GUI
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -285,6 +285,8 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                                                 CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]));
                 gui_window_set_custom_color_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                 CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                gui_window_remove_color_style (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
+                                               A_BOLD | A_UNDERLINE | A_REVERSE);
                 string++;
                 break;
             case GUI_COLOR_SET_WEECHAT_CHAR:
@@ -354,8 +356,8 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                 else
                 {
                     low_char = 0;
-                    if (!gui_window_utf_char_valid (utf_char))
-                        snprintf (utf_char, sizeof (utf_char), ".");
+                    if (!gui_chat_utf_char_valid (utf_char))
+                        snprintf (utf_char, sizeof (utf_char), " ");
                 }
                 
                 size_on_screen = utf8_char_size_screen (utf_char);
@@ -567,7 +569,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                         if (diff > 0)
                         {
                             /*
-                             * TODO: keep some spaces after end of input
+                             * FIXME: keep some spaces after end of input
                              * for example by adding something to diff, like:
                              * diff += (9 - (diff % 10));
                              * but then scroll position has to be saved
@@ -629,6 +631,8 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                             gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                                CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
                                                                CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                            gui_window_remove_color_style (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
+                                                           A_BOLD | A_UNDERLINE | A_REVERSE);
                             wclrtobot (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar);
                         }
                         while (x < bar_window->width)
