@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-curses-chat.c: chat display functions for Curses GUI
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -377,33 +377,23 @@ gui_chat_display_word_raw (struct t_gui_window *window, const char *string,
         {
             memcpy (utf_char, string, next_char - string);
             utf_char[next_char - string] = '\0';
-            if (gui_window_utf_char_valid (utf_char))
+            if (!gui_chat_utf_char_valid (utf_char))
+                snprintf (utf_char, sizeof (utf_char), " ");
+            
+            size_on_screen = utf8_strlen_screen (utf_char);
+            if (max_chars_on_screen > 0)
             {
-                size_on_screen = utf8_strlen_screen (utf_char);
-                if (max_chars_on_screen > 0)
-                {
-                    if (chars_displayed + size_on_screen > max_chars_on_screen)
-                        return chars_displayed;
-                    chars_displayed += size_on_screen;
-                }
-                if (size_on_screen > 0)
-                {
-                    output = string_iconv_from_internal (NULL, utf_char);
-                    wprintw (GUI_WINDOW_OBJECTS(window)->win_chat,
-                             "%s", (output) ? output : utf_char);
-                    if (output)
-                        free (output);
-                }
+                if (chars_displayed + size_on_screen > max_chars_on_screen)
+                    return chars_displayed;
+                chars_displayed += size_on_screen;
             }
-            else
+            if (size_on_screen > 0)
             {
-                if (max_chars_on_screen > 0)
-                {
-                    if (chars_displayed + 1 > max_chars_on_screen)
-                        return chars_displayed;
-                    chars_displayed++;
-                }
-                wprintw (GUI_WINDOW_OBJECTS(window)->win_chat, ".");
+                output = string_iconv_from_internal (NULL, utf_char);
+                wprintw (GUI_WINDOW_OBJECTS(window)->win_chat,
+                         "%s", (output) ? output : utf_char);
+                if (output)
+                    free (output);
             }
         }
         
@@ -449,13 +439,13 @@ gui_chat_display_word (struct t_gui_window *window,
     
     while (data && data[0])
     {
-        /* insert spaces for align text under time/nick */
-        length_align = gui_line_get_align (window->buffer, line, 0);
-        if ((length_align > 0) &&
-            (window->win_chat_cursor_x == 0) &&
-            (*lines_displayed > 0) &&
-            /* TODO: modify arbitraty value for non aligning messages on time/nick? */
-            (length_align < (window->win_chat_width - 5)))
+        /* insert spaces for aligning text under time/nick */
+        length_align = gui_line_get_align (window->buffer, line, 0, 0);
+        if ((length_align > 0)
+            && (window->win_chat_cursor_x == 0)
+            && (*lines_displayed > 0)
+            /* FIXME: modify arbitraty value for non aligning messages on time/nick? */
+            && (length_align < (window->win_chat_width - 5)))
         {
             if (!simulate)
             {
@@ -465,7 +455,8 @@ gui_chat_display_word (struct t_gui_window *window,
                 wclrtoeol (GUI_WINDOW_OBJECTS(window)->win_chat);
             }
             window->win_chat_cursor_x += length_align;
-            if ((CONFIG_INTEGER(config_look_prefix_align) != CONFIG_LOOK_PREFIX_ALIGN_NONE)
+            if ((CONFIG_INTEGER(config_look_align_end_of_lines) == CONFIG_LOOK_ALIGN_END_OF_LINES_MESSAGE)
+                && (CONFIG_INTEGER(config_look_prefix_align) != CONFIG_LOOK_PREFIX_ALIGN_NONE)
                 && (CONFIG_STRING(config_look_prefix_suffix)
                     && CONFIG_STRING(config_look_prefix_suffix)[0]))
             {
@@ -869,7 +860,8 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
             if (word_length > 0)
             {
                 /* spaces + word too long for current line but ok for next line */
-                line_align = gui_line_get_align (window->buffer, line, 1);
+                line_align = gui_line_get_align (window->buffer, line, 1,
+                                                 (lines_displayed == 0) ? 1 : 0);
                 if ((window->win_chat_cursor_x + word_length_with_spaces > gui_chat_get_real_width (window))
                     && (word_length <= gui_chat_get_real_width (window) - line_align))
                 {
