@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-curses-keyboard.c: keyboard functions for Curses GUI
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -88,6 +88,8 @@ gui_keyboard_default_bindings ()
     BIND(/* ^R              */ "ctrl-R",             "/input search_text");
     BIND(/* basckpace       */ "ctrl-H",             "/input delete_previous_char");
     BIND(/* basckpace       */ "ctrl-?",             "/input delete_previous_char");
+    BIND(/* ^_              */ "ctrl-_",             "/input undo");
+    BIND(/* m-_             */ "meta-_",             "/input redo");
     BIND(/* del             */ "meta2-3~",           "/input delete_next_char");
     BIND(/* ^D              */ "ctrl-D",             "/input delete_next_char");
     BIND(/* ^W              */ "ctrl-W",             "/input delete_previous_word");
@@ -338,11 +340,12 @@ gui_keyboard_flush ()
                 if (strcmp (key_str, "^^") == 0)
                     key_str[1] = '\0';
                 
+                gui_buffer_undo_snap (gui_current_window->buffer);
                 gui_input_insert_string (gui_current_window->buffer,
                                          key_str, -1);
                 if (gui_current_window->buffer->completion)
                     gui_completion_stop (gui_current_window->buffer->completion, 0);
-                gui_input_text_changed_modifier_and_signal (gui_current_window->buffer);
+                gui_input_text_changed_modifier_and_signal (gui_current_window->buffer, 1);
             }
             
             /* incremental text search in buffer */
@@ -435,7 +438,7 @@ gui_keyboard_read_cb (void *data, int fd)
         else if (cancel_paste)
             gui_keyboard_paste_cancel ();
         else if (text_added_to_buffer)
-            gui_input_text_changed_modifier_and_signal (gui_current_window->buffer);
+            gui_input_text_changed_modifier_and_signal (gui_current_window->buffer, 0);
     }
     else
     {
