@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-curses-window.c: window display functions for Curses GUI
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -144,24 +144,6 @@ gui_window_objects_free (struct t_gui_window *window, int free_separator)
     }
 }
 
-/*
- * gui_window_utf_char_valid: return 1 if utf char is valid for screen
- *                            otherwise return 0
- */
-
-int
-gui_window_utf_char_valid (const char *utf_char)
-{
-    /* 146 or 0x7F are not valid */
-    if ((((unsigned char)(utf_char[0]) == 146)
-         || ((unsigned char)(utf_char[0]) == 0x7F))
-        && (!utf_char[1]))
-        return 0;
-    
-    /* any other char is valid */
-    return 1;
-}
-
 /*
  * gui_window_get_hline_char: get char used to draw horizontal lines
  *                            Note: ACS_HLINE from ncurses is better for
