@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_CURSES_H
 #define __WEECHAT_GUI_CURSES_H 1
 
@@ -78,7 +78,6 @@ extern int gui_keyboard_read_cb (void *data, int fd);
 /* window functions */
 extern void gui_window_read_terminal_size ();
 extern void gui_window_redraw_buffer (struct t_gui_buffer *buffer);
-extern int gui_window_utf_char_valid (const char *utf_char);
 extern int gui_window_get_hline_char ();
 extern void gui_window_clear (WINDOW *window, int bg);
 extern void gui_window_reset_style (WINDOW *window, int num_color);
@@ -92,4 +91,4 @@ extern void gui_window_set_custom_color_bg (WINDOW *window, int bg);
 extern void gui_window_clrtoeol_with_current_bg (WINDOW *window);
 extern void gui_window_set_title (const char *title);
 
-#endif /* gui-curses.h */
+#endif /* __WEECHAT_GUI_CURSES_H */
