@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-bar-item.c: bar item functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -31,6 +31,7 @@
 
 #include "../core/weechat.h"
 #include "../core/wee-config.h"
+#include "../core/wee-hashtable.h"
 #include "../core/wee-hook.h"
 #include "../core/wee-infolist.h"
 #include "../core/wee-log.h"
@@ -452,30 +453,38 @@ gui_bar_item_update (const char *item_name)
     
     for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
     {
-        gui_bar_get_item_index (ptr_bar, item_name, &index_item, &index_subitem);
-        if ((index_item >= 0) && (index_subitem >= 0))
+        for (index_item = 0; index_item < ptr_bar->items_count; index_item++)
         {
-            if (ptr_bar->bar_window)
+            for (index_subitem = 0;
+                 index_subitem < ptr_bar->items_subcount[index_item];
+                 index_subitem++)
             {
-                ptr_bar->bar_window->items_refresh_needed[index_item][index_subitem] = 1;
-            }
-            else
-            {
-                for (ptr_window = gui_windows; ptr_window;
-                     ptr_window = ptr_window->next_window)
+                if (gui_bar_item_string_is_item (ptr_bar->items_array[index_item][index_subitem],
+                                                 item_name))
                 {
-                    for (ptr_bar_window = ptr_window->bar_windows;
-                         ptr_bar_window;
-                         ptr_bar_window = ptr_bar_window->next_bar_window)
+                    if (ptr_bar->bar_window)
                     {
-                        if (ptr_bar_window->bar == ptr_bar)
+                        ptr_bar->bar_window->items_refresh_needed[index_item][index_subitem] = 1;
+                    }
+                    else
+                    {
+                        for (ptr_window = gui_windows; ptr_window;
+                             ptr_window = ptr_window->next_window)
                         {
-                            ptr_bar_window->items_refresh_needed[index_item][index_subitem] = 1;
+                            for (ptr_bar_window = ptr_window->bar_windows;
+                                 ptr_bar_window;
+                                 ptr_bar_window = ptr_bar_window->next_bar_window)
+                            {
+                                if (ptr_bar_window->bar == ptr_bar)
+                                {
+                                    ptr_bar_window->items_refresh_needed[index_item][index_subitem] = 1;
+                                }
+                            }
                         }
                     }
+                    gui_bar_ask_refresh (ptr_bar);
                 }
             }
-            gui_bar_ask_refresh (ptr_bar);
         }
     }
 }
@@ -585,7 +594,7 @@ char *
 gui_bar_item_default_input_prompt (void *data, struct t_gui_bar_item *item,
                                    struct t_gui_window *window)
 {
-    struct t_gui_buffer_local_var *local_var_nick;
+    const char *nick;
     
     /* make C compiler happy */
     (void) data;
@@ -594,11 +603,12 @@ gui_bar_item_default_input_prompt (void *data, struct t_gui_bar_item *item,
     if (!window)
         window = gui_current_window;
     
-    local_var_nick = gui_buffer_local_var_search (window->buffer, "nick");
-    if (!local_var_nick || !local_var_nick->value)
+    nick = (const char *)hashtable_get (window->buffer->local_variables,
+                                        "nick");
+    if (!nick)
         return NULL;
     
-    return strdup (local_var_nick->value);
+    return strdup (nick);
 }
 
 /*
@@ -1467,6 +1477,8 @@ gui_bar_item_init ()
                       &gui_bar_item_default_buffer_title, NULL);
     gui_bar_item_hook_signal ("buffer_title_changed",
                               gui_bar_item_names[GUI_BAR_ITEM_BUFFER_TITLE]);
+    gui_bar_item_hook_signal ("buffer_switch",
+                              gui_bar_item_names[GUI_BAR_ITEM_BUFFER_TITLE]);
     
     /* buffer nicklist */
     gui_bar_item_new (NULL,
