@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-bar-window.c: bar window functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -448,19 +448,13 @@ gui_bar_window_content_get_with_filling (struct t_gui_bar_window *bar_window,
         return NULL;
     
     snprintf (reinit_color, sizeof (reinit_color),
-              "%c%c%02d,%02d",
-              GUI_COLOR_COLOR_CHAR,
-              GUI_COLOR_FG_BG_CHAR,
-              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+              "%c",
+              GUI_COLOR_RESET_CHAR);
     length_reinit_color = strlen (reinit_color);
     
     snprintf (reinit_color_space, sizeof (reinit_color_space),
-              "%c%c%02d,%02d ",
-              GUI_COLOR_COLOR_CHAR,
-              GUI_COLOR_FG_BG_CHAR,
-              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+              "%c ",
+              GUI_COLOR_RESET_CHAR);
     length_reinit_color_space = strlen (reinit_color_space);
     
     content = NULL;
