@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-bar.c: bar functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -298,45 +298,6 @@ gui_bar_get_filling (struct t_gui_bar *bar)
     return CONFIG_INTEGER(bar->options[GUI_BAR_OPTION_FILLING_LEFT_RIGHT]);
 }
 
-/*
- * gui_bar_get_item_index: return index of item and sub item in bar (position
- *                         of item in items list)
- *                         for example, if items are:
- *                            item1,sub1+sub2+sub3,item3
- *                         index of sub3 is 1, sub index is 2
- *                         return -1 for index and sub index if item is not
- *                         found in bar
- */
-
-void
-gui_bar_get_item_index (struct t_gui_bar *bar, const char *item_name,
-                        int *index_item, int *index_subitem)
-{
-    int i, j;
-    
-    *index_item = -1;
-    *index_subitem = -1;
-    
-    if (!bar || !item_name || !item_name[0])
-        return;
-    
-    for (i = 0; i < bar->items_count; i++)
-    {
-        for (j = 0; j < bar->items_subcount[i]; j++)
-        {
-            /* skip non letters chars at beginning (prefix) */
-            if (gui_bar_item_string_is_item (bar->items_array[i][j], item_name))
-            {
-                *index_item = i;
-                *index_subitem = j;
-                return;
-            }
-        }
-    }
-    
-    /* item is not in bar */
-}
-
 /*
  * gui_bar_find_pos: find position for a bar in list (keeping list sorted
  *                   by priority)
