@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_BAR_H
 #define __WEECHAT_GUI_BAR_H 1
 
@@ -114,9 +114,6 @@ extern int gui_bar_search_option (const char *option_name);
 extern int gui_bar_search_type (const char *type);
 extern int gui_bar_search_position (const char *position);
 extern enum t_gui_bar_filling gui_bar_get_filling (struct t_gui_bar *bar);
-extern void gui_bar_get_item_index (struct t_gui_bar *bar,
-                                    const char *item_name,
-                                    int *index_item, int *index_subitem);
 extern int gui_bar_check_conditions_for_window (struct t_gui_bar *bar,
                                                 struct t_gui_window *window);
 extern int gui_bar_root_get_size (struct t_gui_bar *bar,
@@ -155,4 +152,4 @@ extern int gui_bar_add_to_infolist (struct t_infolist *infolist,
                                     struct t_gui_bar *bar);
 extern void gui_bar_print_log ();
 
-#endif /* gui-bar.h */
+#endif /* __WEECHAT_GUI_BAR_H */
