@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-buffer.c: buffer functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -36,6 +36,7 @@
 
 #include "../core/weechat.h"
 #include "../core/wee-config.h"
+#include "../core/wee-hashtable.h"
 #include "../core/wee-hook.h"
 #include "../core/wee-infolist.h"
 #include "../core/wee-list.h"
@@ -124,77 +125,25 @@ gui_buffer_find_pos (struct t_gui_buffer *buffer)
     return NULL;
 }
 
-/*
- * gui_buffer_local_var_search: search a local variable with name
- */
-
-struct t_gui_buffer_local_var *
-gui_buffer_local_var_search (struct t_gui_buffer *buffer, const char *name)
-{
-    struct t_gui_buffer_local_var *ptr_local_var;
-    
-    if (!buffer || !name)
-        return NULL;
-    
-    for (ptr_local_var = buffer->local_variables; ptr_local_var;
-         ptr_local_var = ptr_local_var->next_var)
-    {
-        if (strcmp (ptr_local_var->name, name) == 0)
-            return ptr_local_var;
-    }
-    
-    /* local variable not found */
-    return NULL;
-}
-
 /*
  * gui_buffer_local_var_add: add a new local variable to a buffer
  */
 
-struct t_gui_buffer_local_var *
+void
 gui_buffer_local_var_add (struct t_gui_buffer *buffer, const char *name,
                           const char *value)
 {
-    struct t_gui_buffer_local_var *new_local_var;
+    void *ptr_value;
     
-    if (!buffer || !name || !value)
-        return NULL;
+    if (!buffer || !buffer->local_variables || !name || !value)
+        return;
     
-    new_local_var = gui_buffer_local_var_search (buffer, name);
-    if (new_local_var)
-    {
-        if (new_local_var->name)
-            free (new_local_var->name);
-        if (new_local_var->value)
-            free (new_local_var->value);
-        new_local_var->name = strdup (name);
-        new_local_var->value = strdup (value);
-        
-        hook_signal_send ("buffer_localvar_changed",
-                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
-    }
-    else
-    {
-        new_local_var = malloc (sizeof (*new_local_var));
-        if (new_local_var)
-        {
-            new_local_var->name = strdup (name);
-            new_local_var->value = strdup (value);
-            
-            new_local_var->prev_var = buffer->last_local_var;
-            new_local_var->next_var = NULL;
-            if (buffer->local_variables)
-                buffer->last_local_var->next_var = new_local_var;
-            else
-                buffer->local_variables = new_local_var;
-            buffer->last_local_var = new_local_var;
-            
-            hook_signal_send ("buffer_localvar_added",
-                              WEECHAT_HOOK_SIGNAL_POINTER, buffer);
-        }
-    }
-    
-    return new_local_var;
+    ptr_value = hashtable_get (buffer->local_variables, name);
+    hashtable_set (buffer->local_variables,
+                   (void *)name, (void *)value);
+    hook_signal_send ((ptr_value) ?
+                      "buffer_localvar_changed" : "buffer_localvar_added",
+                      WEECHAT_HOOK_SIGNAL_POINTER, buffer);
 }
 
 /*
@@ -202,32 +151,20 @@ gui_buffer_local_var_add (struct t_gui_buffer *buffer, const char *name,
  */
 
 void
-gui_buffer_local_var_remove (struct t_gui_buffer *buffer,
-                             struct t_gui_buffer_local_var *local_var)
+gui_buffer_local_var_remove (struct t_gui_buffer *buffer, const char *name)
 {
-    if (!buffer || !local_var)
+    void *ptr_value;
+    
+    if (!buffer || !buffer->local_variables || !name)
         return;
     
-    /* free data */
-    if (local_var->name)
-        free (local_var->name);
-    if (local_var->value)
-        free (local_var->value);
-    
-    /* remove local variable from list */
-    if (local_var->prev_var)
-        (local_var->prev_var)->next_var = local_var->next_var;
-    if (local_var->next_var)
-        (local_var->next_var)->prev_var = local_var->prev_var;
-    if (buffer->local_variables == local_var)
-        buffer->local_variables = local_var->next_var;
-    if (buffer->last_local_var == local_var)
-        buffer->last_local_var = local_var->prev_var;
-    
-    free (local_var);
-
-    hook_signal_send ("buffer_localvar_removed",
-                      WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+    ptr_value = hashtable_get (buffer->local_variables, name);
+    if (ptr_value)
+    {
+        hashtable_remove (buffer->local_variables, name);
+        hook_signal_send ("buffer_localvar_removed",
+                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
+    }
 }
 
 /*
@@ -237,12 +174,11 @@ gui_buffer_local_var_remove (struct t_gui_buffer *buffer,
 void
 gui_buffer_local_var_remove_all (struct t_gui_buffer *buffer)
 {
-    if (buffer)
+    if (buffer && buffer->local_variables)
     {
-        while (buffer->local_variables)
-        {
-            gui_buffer_local_var_remove (buffer, buffer->local_variables);
-        }
+        hashtable_remove_all (buffer->local_variables);
+        hook_signal_send ("buffer_localvar_removed",
+                          WEECHAT_HOOK_SIGNAL_POINTER, buffer);
     }
 }
 
@@ -477,6 +413,16 @@ gui_buffer_new (struct t_weechat_plugin *plugin,
         new_buffer->input_buffer_pos = 0;
         new_buffer->input_buffer_1st_display = 0;
         
+        /* undo for input */
+        (new_buffer->input_undo_snap).data = NULL;
+        (new_buffer->input_undo_snap).pos = 0;
+        (new_buffer->input_undo_snap).prev_undo = NULL; /* not used */
+        (new_buffer->input_undo_snap).next_undo = NULL; /* not used */
+        new_buffer->input_undo = NULL;
+        new_buffer->last_input_undo = NULL;
+        new_buffer->ptr_input_undo = NULL;
+        new_buffer->input_undo_count = 0;
+        
         /* init completion */
         new_completion = malloc (sizeof (*new_completion));
         if (new_completion)
@@ -509,10 +455,15 @@ gui_buffer_new (struct t_weechat_plugin *plugin,
         new_buffer->keys_count = 0;
         
         /* local variables */
-        new_buffer->local_variables = NULL;
-        new_buffer->last_local_var = NULL;
-        gui_buffer_local_var_add (new_buffer, "plugin", plugin_get_name (plugin));
-        gui_buffer_local_var_add (new_buffer, "name", name);
+        new_buffer->local_variables = hashtable_new (8,
+                                                     WEECHAT_HASHTABLE_STRING,
+                                                     WEECHAT_HASHTABLE_STRING,
+                                                     NULL,
+                                                     NULL);
+        hashtable_set (new_buffer->local_variables,
+                       "plugin", (void *)plugin_get_name (plugin));
+        hashtable_set (new_buffer->local_variables,
+                       "name", (void *)name);
         
         /* add buffer to buffers list */
         first_buffer_creation = (gui_buffers == NULL);
@@ -580,8 +531,7 @@ gui_buffer_string_replace_local_var (struct t_gui_buffer *buffer,
 {
     int length, length_var, index_string, index_result;
     char *result, *local_var;
-    const char *pos_end_name;
-    struct t_gui_buffer_local_var *ptr_local_var;
+    const char *pos_end_name, *ptr_value;
     
     if (!string)
         return NULL;
@@ -613,11 +563,11 @@ gui_buffer_string_replace_local_var (struct t_gui_buffer *buffer,
                                                 pos_end_name - (string + index_string + 1));
                     if (local_var)
                     {
-                        ptr_local_var = gui_buffer_local_var_search (buffer,
-                                                                     local_var);
-                        if (ptr_local_var)
+                        ptr_value = (const char *)hashtable_get (buffer->local_variables,
+                                                                 local_var);
+                        if (ptr_value)
                         {
-                            length_var = strlen (ptr_local_var->value);
+                            length_var = strlen (ptr_value);
                             length += length_var;
                             result = realloc (result, length);
                             if (!result)
@@ -625,7 +575,7 @@ gui_buffer_string_replace_local_var (struct t_gui_buffer *buffer,
                                 free (local_var);
                                 return NULL;
                             }
-                            strcpy (result + index_result, ptr_local_var->value);
+                            strcpy (result + index_result, ptr_value);
                             index_result += length_var;
                             index_string += strlen (local_var) + 1;
                         }
@@ -767,7 +717,7 @@ gui_buffer_get_integer (struct t_gui_buffer *buffer, const char *property)
 const char *
 gui_buffer_get_string (struct t_gui_buffer *buffer, const char *property)
 {
-    struct t_gui_buffer_local_var *ptr_local_var;
+    const char *ptr_value;
     
     if (buffer && property)
     {
@@ -789,9 +739,10 @@ gui_buffer_get_string (struct t_gui_buffer *buffer, const char *property)
             return buffer->highlight_tags;
         else if (string_strncasecmp (property, "localvar_", 9) == 0)
         {
-            ptr_local_var = gui_buffer_local_var_search (buffer, property + 9);
-            if (ptr_local_var)
-                return ptr_local_var->value;
+            ptr_value = (const char *)hashtable_get (buffer->local_variables,
+                                                     property + 9);
+            if (ptr_value)
+                return ptr_value;
         }
     }
     
@@ -1175,7 +1126,6 @@ gui_buffer_set (struct t_gui_buffer *buffer, const char *property,
 {
     long number;
     char *error;
-    struct t_gui_buffer_local_var *ptr_local_var;
     
     if (!property || !value)
         return;
@@ -1321,9 +1271,9 @@ gui_buffer_set (struct t_gui_buffer *buffer, const char *property,
     }
     else if (string_strcasecmp (property, "input") == 0)
     {
-        gui_input_delete_line (buffer);
-        gui_input_insert_string (buffer, value, 0);
-        gui_input_text_changed_modifier_and_signal (buffer);
+        gui_buffer_undo_snap (buffer);
+        gui_input_replace_input (buffer, value);
+        gui_input_text_changed_modifier_and_signal (buffer, 1);
     }
     else if (string_strcasecmp (property, "input_pos") == 0)
     {
@@ -1346,9 +1296,7 @@ gui_buffer_set (struct t_gui_buffer *buffer, const char *property,
     }
     else if (string_strncasecmp (property, "localvar_del_", 13) == 0)
     {
-        ptr_local_var = gui_buffer_local_var_search (buffer, property + 13);
-        if (ptr_local_var)
-            gui_buffer_local_var_remove (buffer, ptr_local_var);
+        gui_buffer_local_var_remove (buffer, property + 13);
     }
 }
 
@@ -1841,6 +1789,7 @@ gui_buffer_close (struct t_gui_buffer *buffer)
         free (buffer->short_name);
     if (buffer->input_buffer)
         free (buffer->input_buffer);
+    gui_buffer_undo_free_all (buffer);
     if (buffer->completion)
         gui_completion_free (buffer->completion);
     gui_history_buffer_free (buffer);
@@ -2302,6 +2251,178 @@ gui_buffer_unmerge (struct t_gui_buffer *buffer, int number)
                       WEECHAT_HOOK_SIGNAL_POINTER, buffer);
 }
 
+/*
+ * gui_buffer_undo_snap: do a "snapshot" of buffer input (save content and
+ *                       position)
+ */
+
+void
+gui_buffer_undo_snap (struct t_gui_buffer *buffer)
+{
+    if ((buffer->input_undo_snap).data)
+    {
+        free ((buffer->input_undo_snap).data);
+        (buffer->input_undo_snap).data = NULL;
+    }
+    (buffer->input_undo_snap).pos = 0;
+    
+    if (CONFIG_INTEGER(config_look_input_undo_max) > 0)
+    {
+        (buffer->input_undo_snap).data = (buffer->input_buffer) ?
+            strdup (buffer->input_buffer) : NULL;
+        (buffer->input_undo_snap).pos = buffer->input_buffer_pos;
+    }
+}
+
+/*
+ * gui_buffer_undo_snap_free: free "snapshot" of buffer input
+ */
+
+void
+gui_buffer_undo_snap_free (struct t_gui_buffer *buffer)
+{
+    if ((buffer->input_undo_snap).data)
+    {
+        free ((buffer->input_undo_snap).data);
+        (buffer->input_undo_snap).data = NULL;
+    }
+    (buffer->input_undo_snap).pos = 0;
+}
+
+/*
+ * gui_buffer_undo_add: add undo in list, with current input buffer + postion
+ *                      if before_undo is not NULL, then undo is added before
+ *                      this undo, otherwise it is added to the end of list
+ */
+
+void
+gui_buffer_undo_add (struct t_gui_buffer *buffer)
+{
+    struct t_gui_input_undo *new_undo;
+    
+    /* undo disabled by config */
+    if (CONFIG_INTEGER(config_look_input_undo_max) == 0)
+        goto end;
+    
+    /*
+     * if nothing has changed since snapshot of input buffer, then do nothing
+     * (just discard snapshot)
+     */
+    if ((buffer->input_undo_snap).data
+        && (strcmp (buffer->input_buffer, (buffer->input_undo_snap).data) == 0))
+    {
+        goto end;
+    }
+    
+    /* max number of undo reached? */
+    if ((buffer->input_undo_count > 0)
+        && (buffer->input_undo_count >= CONFIG_INTEGER(config_look_input_undo_max) + 1))
+    {
+        /* remove older undo in buffer (first in list) */
+        gui_buffer_undo_free (buffer, buffer->input_undo);
+    }
+    
+    /* remove all undos after current undo */
+    if (buffer->ptr_input_undo)
+    {
+        while (buffer->ptr_input_undo->next_undo)
+        {
+            gui_buffer_undo_free (buffer, buffer->ptr_input_undo->next_undo);
+        }
+    }
+    
+    /* if input is the same as current undo, then do not add it */
+    if (buffer->ptr_input_undo
+        && (buffer->ptr_input_undo)->data
+        && (buffer->input_undo_snap).data
+        && (strcmp ((buffer->input_undo_snap).data, (buffer->ptr_input_undo)->data) == 0))
+    {
+        goto end;
+    }
+    
+    new_undo = (struct t_gui_input_undo *)malloc (sizeof (*new_undo));
+    if (!new_undo)
+        goto end;
+    
+    if ((buffer->input_undo_snap).data)
+    {
+        new_undo->data = strdup ((buffer->input_undo_snap).data);
+        new_undo->pos = (buffer->input_undo_snap).pos;
+    }
+    else
+    {
+        new_undo->data = (buffer->input_buffer) ?
+            strdup (buffer->input_buffer) : NULL;
+        new_undo->pos = buffer->input_buffer_pos;
+    }
+    
+    /* add undo to the list */
+    new_undo->prev_undo = buffer->last_input_undo;
+    new_undo->next_undo = NULL;
+    if (buffer->input_undo)
+        (buffer->last_input_undo)->next_undo = new_undo;
+    else
+        buffer->input_undo = new_undo;
+    buffer->last_input_undo = new_undo;
+    
+    buffer->ptr_input_undo = new_undo;
+    buffer->input_undo_count++;
+    
+end:
+    gui_buffer_undo_snap_free (buffer);
+}
+
+/*
+ * gui_buffer_undo_free: free undo and remove it from list
+ */
+
+void
+gui_buffer_undo_free (struct t_gui_buffer *buffer,
+                      struct t_gui_input_undo *undo)
+{
+    /* update current undo if needed */
+    if (buffer->ptr_input_undo == undo)
+    {
+        if ((buffer->ptr_input_undo)->next_undo)
+            buffer->ptr_input_undo = (buffer->ptr_input_undo)->next_undo;
+        else
+            buffer->ptr_input_undo = (buffer->ptr_input_undo)->prev_undo;
+    }
+    
+    /* free data */
+    if (undo->data)
+        free (undo->data);
+    
+    /* remove undo from list */
+    if (undo->prev_undo)
+        (undo->prev_undo)->next_undo = undo->next_undo;
+    if (undo->next_undo)
+        (undo->next_undo)->prev_undo = undo->prev_undo;
+    if (buffer->input_undo == undo)
+        buffer->input_undo = undo->next_undo;
+    if (buffer->last_input_undo == undo)
+        buffer->last_input_undo = undo->prev_undo;
+    
+    free (undo);
+    
+    buffer->input_undo_count--;
+}
+
+/*
+ * gui_buffer_undo_free_all: free all undos of a buffer
+ */
+
+void
+gui_buffer_undo_free_all (struct t_gui_buffer *buffer)
+{
+    gui_buffer_undo_snap_free (buffer);
+    
+    while (buffer->input_undo)
+    {
+        gui_buffer_undo_free (buffer, buffer->input_undo);
+    }
+}
+
 /*
  * gui_buffer_visited_search: search a visited buffer in list of visited buffers
  */
@@ -2499,7 +2620,6 @@ gui_buffer_add_to_infolist (struct t_infolist *infolist,
 {
     struct t_infolist_item *ptr_item;
     struct t_gui_key *ptr_key;
-    struct t_gui_buffer_local_var *ptr_local_var;
     char option_name[64];
     int i;
     
@@ -2597,20 +2717,8 @@ gui_buffer_add_to_infolist (struct t_infolist *infolist,
     }
     if (!infolist_new_var_integer (ptr_item, "keys_count", buffer->keys_count))
         return 0;
-    i = 0;
-    for (ptr_local_var = buffer->local_variables; ptr_local_var;
-         ptr_local_var = ptr_local_var->next_var)
-    {
-        snprintf (option_name, sizeof (option_name), "localvar_name_%05d", i);
-        if (!infolist_new_var_string (ptr_item, option_name,
-                                      ptr_local_var->name))
-            return 0;
-        snprintf (option_name, sizeof (option_name), "localvar_value_%05d", i);
-        if (!infolist_new_var_string (ptr_item, option_name,
-                                      ptr_local_var->value))
-            return 0;
-        i++;
-    }
+    if (!hashtable_add_to_infolist (buffer->local_variables, ptr_item, "localvar"))
+        return 0;
     
     return 1;
 }
@@ -2692,9 +2800,9 @@ void
 gui_buffer_print_log ()
 {
     struct t_gui_buffer *ptr_buffer;
-    struct t_gui_buffer_local_var *ptr_local_var;
     struct t_gui_line *ptr_line;
     struct t_gui_buffer_visited *ptr_buffer_visited;
+    struct t_gui_input_undo *ptr_undo;
     char *tags;
     int num;
     
@@ -2742,6 +2850,20 @@ gui_buffer_print_log ()
         log_printf ("  input_buffer_length. . : %d",    ptr_buffer->input_buffer_length);
         log_printf ("  input_buffer_pos . . . : %d",    ptr_buffer->input_buffer_pos);
         log_printf ("  input_buffer_1st_disp. : %d",    ptr_buffer->input_buffer_1st_display);
+        log_printf ("  input_undo_snap.data . : '%s'",  (ptr_buffer->input_undo_snap).data);
+        log_printf ("  input_undo_snap.pos. . : %d",    (ptr_buffer->input_undo_snap).pos);
+        log_printf ("  input_undo . . . . . . : 0x%lx", ptr_buffer->input_undo);
+        log_printf ("  last_input_undo. . . . : 0x%lx", ptr_buffer->last_input_undo);
+        log_printf ("  ptr_input_undo . . . . : 0x%lx", ptr_buffer->ptr_input_undo);
+        log_printf ("  input_undo_count . . . : %d",    ptr_buffer->input_undo_count);
+        num = 0;
+        for (ptr_undo = ptr_buffer->input_undo; ptr_undo;
+             ptr_undo = ptr_undo->next_undo)
+        {
+            log_printf ("    undo[%04d] . . . . . : 0x%lx ('%s' / %d)",
+                        num, ptr_undo, ptr_undo->data, ptr_undo->pos);
+            num++;
+        }
         log_printf ("  completion . . . . . . : 0x%lx", ptr_buffer->completion);
         log_printf ("  history. . . . . . . . : 0x%lx", ptr_buffer->history);
         log_printf ("  last_history . . . . . : 0x%lx", ptr_buffer->last_history);
@@ -2759,7 +2881,6 @@ gui_buffer_print_log ()
         log_printf ("  last_key . . . . . . . : 0x%lx", ptr_buffer->last_key);
         log_printf ("  keys_count . . . . . . : %d",    ptr_buffer->keys_count);
         log_printf ("  local_variables. . . . : 0x%lx", ptr_buffer->local_variables);
-        log_printf ("  last_local_var . . . . : 0x%lx", ptr_buffer->last_local_var);
         log_printf ("  prev_buffer. . . . . . : 0x%lx", ptr_buffer->prev_buffer);
         log_printf ("  next_buffer. . . . . . : 0x%lx", ptr_buffer->next_buffer);
         
@@ -2769,20 +2890,11 @@ gui_buffer_print_log ()
             log_printf ("  => keys:");
             gui_keyboard_print_log (ptr_buffer);
         }
-
+        
         if (ptr_buffer->local_variables)
         {
-            log_printf ("");
-            log_printf ("  => local_variables:");
-            for (ptr_local_var = ptr_buffer->local_variables; ptr_local_var;
-                 ptr_local_var = ptr_local_var->next_var)
-            {
-                log_printf ("");
-                log_printf ("    [local variable (addr:0x%lx)]",
-                            ptr_local_var);
-                log_printf ("      name . . . . . . . : '%s'", ptr_local_var->name);
-                log_printf ("      value. . . . . . . : '%s'", ptr_local_var->value);
-            }
+            hashtable_print_log (ptr_buffer->local_variables,
+                                 "local_variables");
         }
         
         log_printf ("");
