@@ -1,25 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_BUFFER_H
 #define __WEECHAT_GUI_BUFFER_H 1
 
+struct t_hashtable;
 struct t_gui_window;
 struct t_infolist;
 
@@ -49,12 +50,12 @@ enum t_gui_buffer_notify
 
 /* buffer structures */
 
-struct t_gui_buffer_local_var
+struct t_gui_input_undo
 {
-    char *name;                        /* variable name                     */
-    char *value;                       /* value                             */
-    struct t_gui_buffer_local_var *prev_var; /* link to previous variable   */
-    struct t_gui_buffer_local_var *next_var; /* link to next variable       */
+    char *data;                        /* content of input buffer           */
+    int pos;                           /* position of cursor in buffer      */
+    struct t_gui_input_undo *prev_undo;/* link to previous undo             */
+    struct t_gui_input_undo *next_undo;/* link to next undo                 */
 };
 
 struct t_gui_buffer
@@ -133,6 +134,13 @@ struct t_gui_buffer
     int input_buffer_pos;              /* position into buffer              */
     int input_buffer_1st_display;      /* first char displayed on screen    */
     
+    /* undo/redo for input */
+    struct t_gui_input_undo input_undo_snap;  /* snapshot of input buffer   */
+    struct t_gui_input_undo *input_undo;      /* undo for input             */
+    struct t_gui_input_undo *last_input_undo; /* last undo for input        */
+    struct t_gui_input_undo *ptr_input_undo;  /* pointer to current undo    */
+    int input_undo_count;              /* number of undos                   */
+    
     /* completion */
     struct t_gui_completion *completion; /* completion                      */
     
@@ -161,8 +169,7 @@ struct t_gui_buffer
     int keys_count;                    /* number of keys in buffer          */
     
     /* local variables */
-    struct t_gui_buffer_local_var *local_variables; /* local variables      */
-    struct t_gui_buffer_local_var *last_local_var;  /* last local variable  */
+    struct t_hashtable *local_variables; /* local variables                 */
     
     /* link to previous/next buffer */
     struct t_gui_buffer *prev_buffer;  /* link to previous buffer           */
@@ -193,8 +200,6 @@ extern char *gui_buffer_properties_set[];
 
 /* buffer functions */
 
-extern struct t_gui_buffer_local_var *gui_buffer_local_var_search (struct t_gui_buffer *buffer,
-                                                                   const char *name);
 extern void gui_buffer_notify_set_all ();
 extern struct t_gui_buffer *gui_buffer_new (struct t_weechat_plugin *plugin,
                                             const char *name,
@@ -252,6 +257,12 @@ extern void gui_buffer_move_to_number (struct t_gui_buffer *buffer, int number);
 extern void gui_buffer_merge (struct t_gui_buffer *buffer,
                               struct t_gui_buffer *target_buffer);
 extern void gui_buffer_unmerge (struct t_gui_buffer *buffer, int number);
+extern void gui_buffer_undo_snap (struct t_gui_buffer *buffer);
+extern void gui_buffer_undo_snap_free (struct t_gui_buffer *buffer);
+extern void gui_buffer_undo_add (struct t_gui_buffer *buffer);
+extern void gui_buffer_undo_free (struct t_gui_buffer *buffer,
+                                  struct t_gui_input_undo *undo);
+extern void gui_buffer_undo_free_all (struct t_gui_buffer *buffer);
 extern struct t_gui_buffer_visited *gui_buffer_visited_search_by_number (int number);
 extern void gui_buffer_visited_remove (struct t_gui_buffer_visited *buffer_visited);
 extern void gui_buffer_visited_remove_by_buffer (struct t_gui_buffer *buffer);
@@ -263,4 +274,4 @@ extern int gui_buffer_add_to_infolist (struct t_infolist *infolist,
 extern void gui_buffer_dump_hexa (struct t_gui_buffer *buffer);
 extern void gui_buffer_print_log ();
 
-#endif /* gui-buffer.h */
+#endif /* __WEECHAT_GUI_BUFFER_H */
