@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-chat.c: chat functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -118,6 +118,28 @@ gui_chat_prefix_build ()
     gui_chat_prefix[GUI_CHAT_PREFIX_QUIT] = strdup (prefix);
 }
 
+/*
+ * gui_chat_utf_char_valid: return 1 if utf char is valid for screen
+ *                          otherwise return 0
+ */
+
+int
+gui_chat_utf_char_valid (const char *utf_char)
+{
+    /* chars below 32 are not valid */
+    if ((unsigned char)utf_char[0] < 32)
+        return 0;
+    
+    /* 146 or 0x7F are not valid */
+    if ((((unsigned char)(utf_char[0]) == 146)
+         || ((unsigned char)(utf_char[0]) == 0x7F))
+        && (!utf_char[1]))
+        return 0;
+    
+    /* any other char is valid */
+    return 1;
+}
+
 /*
  * gui_chat_strlen_screen: returns number of char needed on sreen to display a
  *                         word special chars like color, bold, .. are ignored
@@ -134,7 +156,7 @@ gui_chat_strlen_screen (const char *string)
         string = gui_chat_string_next_char (NULL, (unsigned char *)string, 0);
         if (string)
         {
-            size_on_screen = (((unsigned char)string[0]) < 32) ? 1 : utf8_char_size_screen (string);
+            size_on_screen = (gui_chat_utf_char_valid (string)) ? utf8_char_size_screen (string) : 1;
             if (size_on_screen > 0)
                 length += size_on_screen;
             string = utf8_next_char (string);
