@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_CHAT_H
 #define __WEECHAT_GUI_CHAT_H 1
 
@@ -59,6 +59,7 @@ extern struct t_gui_buffer *gui_chat_mute_buffer;
 
 extern void gui_chat_init ();
 extern void gui_chat_prefix_build ();
+extern int gui_chat_utf_char_valid (const char *utf_char);
 extern int gui_chat_strlen_screen (const char *string);
 extern char *gui_chat_string_add_offset (const char *string, int offset);
 extern int gui_chat_string_real_pos (const char *string, int pos);
@@ -86,4 +87,4 @@ extern void gui_chat_draw (struct t_gui_buffer *buffer, int erase);
 extern void gui_chat_draw_line (struct t_gui_buffer *buffer,
                                 struct t_gui_line *line);
 
-#endif /* gui-chat.h */
+#endif /* __WEECHAT_GUI_CHAT_H */
