@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-color.c: color functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -267,59 +267,53 @@ gui_color_decode (const char *string, const char *replacement)
         {
             case GUI_COLOR_COLOR_CHAR:
                 ptr_string++;
+                switch (ptr_string[0])
+                {
+                    case GUI_COLOR_FG_CHAR:
+                    case GUI_COLOR_BG_CHAR:
+                        if (ptr_string[1] && ptr_string[2])
+                            ptr_string += 3;
+                        break;
+                    case GUI_COLOR_FG_BG_CHAR:
+                        if (ptr_string[1] && ptr_string[2] && (ptr_string[3] == ',')
+                            && ptr_string[4] && ptr_string[5])
+                            ptr_string += 6;
+                        break;
+                    case GUI_COLOR_BAR_CHAR:
+                        ptr_string++;
+                        switch (ptr_string[0])
+                        {
+                            case GUI_COLOR_BAR_FG_CHAR:
+                            case GUI_COLOR_BAR_BG_CHAR:
+                            case GUI_COLOR_BAR_DELIM_CHAR:
+                            case GUI_COLOR_BAR_START_INPUT_CHAR:
+                            case GUI_COLOR_BAR_START_INPUT_HIDDEN_CHAR:
+                            case GUI_COLOR_BAR_MOVE_CURSOR_CHAR:
+                                ptr_string++;
+                                break;
+                        }
+                        break;
+                    default:
+                        if (isdigit (ptr_string[0]) && isdigit (ptr_string[1]))
+                            ptr_string += 2;
+                        break;
+                }
                 if (replacement && replacement[0])
                 {
                     out[out_pos] = replacement[0];
                     out_pos++;
                 }
-                else
-                {
-                    switch (ptr_string[0])
-                    {
-                        case GUI_COLOR_FG_CHAR:
-                        case GUI_COLOR_BG_CHAR:
-                            if (ptr_string[1] && ptr_string[2])
-                                ptr_string += 3;
-                            break;
-                        case GUI_COLOR_FG_BG_CHAR:
-                            if (ptr_string[1] && ptr_string[2] && (ptr_string[3] == ',')
-                                && ptr_string[4] && ptr_string[5])
-                                ptr_string += 6;
-                            break;
-                        case GUI_COLOR_BAR_CHAR:
-                            ptr_string++;
-                            switch (ptr_string[0])
-                            {
-                                case GUI_COLOR_BAR_FG_CHAR:
-                                case GUI_COLOR_BAR_BG_CHAR:
-                                case GUI_COLOR_BAR_DELIM_CHAR:
-                                case GUI_COLOR_BAR_START_INPUT_CHAR:
-                                case GUI_COLOR_BAR_START_INPUT_HIDDEN_CHAR:
-                                case GUI_COLOR_BAR_MOVE_CURSOR_CHAR:
-                                    ptr_string++;
-                                    break;
-                            }
-                            break;
-                        default:
-                            if (isdigit (ptr_string[0]) && isdigit (ptr_string[1]))
-                                ptr_string += 2;
-                            break;
-                    }
-                }
                 break;
             case GUI_COLOR_SET_WEECHAT_CHAR:
             case GUI_COLOR_REMOVE_WEECHAT_CHAR:
                 ptr_string++;
+                if (ptr_string[0])
+                    ptr_string++;
                 if (replacement && replacement[0])
                 {
                     out[out_pos] = replacement[0];
                     out_pos++;
                 }
-                else
-                {
-                    if (ptr_string[0])
-                        ptr_string++;
-                }
                 break;
             case GUI_COLOR_RESET_CHAR:
                 ptr_string++;
