@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_INPUT_H
 #define __WEECHAT_GUI_INPUT_H 1
 
@@ -29,8 +29,11 @@ extern char *gui_input_clipboard;
 
 /* input functions */
 
+extern void gui_input_replace_input (struct t_gui_buffer *buffer,
+                                     const char *new_input);
 extern void gui_input_paste_pending_signal ();
-extern void gui_input_text_changed_modifier_and_signal (struct t_gui_buffer *buffer);
+extern void gui_input_text_changed_modifier_and_signal (struct t_gui_buffer *buffer,
+                                                        int save_undo);
 extern void gui_input_move (struct t_gui_buffer *buffer, char *target,
                             const char *source, int size);
 extern void gui_input_set_pos (struct t_gui_buffer *buffer, int pos);
@@ -72,5 +75,7 @@ extern void gui_input_set_unread_buffer (struct t_gui_buffer *buffer);
 extern void gui_input_switch_active_buffer (struct t_gui_window *window);
 extern void gui_input_switch_active_buffer_previous (struct t_gui_window *window);
 extern void gui_input_insert (struct t_gui_buffer *buffer, const char *args);
+extern void gui_input_undo (struct t_gui_buffer *buffer);
+extern void gui_input_redo (struct t_gui_buffer *buffer);
 
-#endif /* gui-input.h */
+#endif /* __WEECHAT_GUI_INPUT_H */
