@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-keyboard: keyboard functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -136,7 +136,7 @@ gui_keyboard_grab_end ()
             }
             if (gui_current_window->buffer->completion)
                 gui_completion_stop (gui_current_window->buffer->completion, 1);
-            gui_input_text_changed_modifier_and_signal (gui_current_window->buffer);
+            gui_input_text_changed_modifier_and_signal (gui_current_window->buffer, 1);
         }
         free (expanded_key);
     }
@@ -551,16 +551,6 @@ gui_keyboard_pressed (const char *key_str)
                 }
             }
             
-            if (gui_current_window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
-            {
-                /* TODO: execute keyboard hooks */
-                /*(void) plugin_keyboard_handler_exec (
-                    (ptr_key->command) ?
-                    ptr_key->command : gui_keyboard_function_search_by_ptr (ptr_key->function),
-                    buffer_before_key,
-                    gui_current_window->buffer->input_buffer);*/
-            }
-            
             if (buffer_before_key)
                 free (buffer_before_key);
         }
