@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * gui-line.c: line functions (used by all GUI)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -85,10 +85,17 @@ gui_lines_free (struct t_gui_lines *lines)
 
 int
 gui_line_get_align (struct t_gui_buffer *buffer, struct t_gui_line *line,
-                    int with_suffix)
+                    int with_suffix, int first_line)
 {
     int length_time, length_buffer, length_suffix;
     
+    /* return immediately if alignment for end of lines is "time" */
+    if (!first_line
+        && (CONFIG_INTEGER(config_look_align_end_of_lines) == CONFIG_LOOK_ALIGN_END_OF_LINES_TIME))
+    {
+        return 0;
+    }
+    
     /* length of time */
     if (buffer->time_for_each_line)
     {
@@ -97,6 +104,13 @@ gui_line_get_align (struct t_gui_buffer *buffer, struct t_gui_line *line,
     else
         length_time = 0;
     
+    /* return immediately if alignment for end of lines is "buffer" */
+    if (!first_line
+        && (CONFIG_INTEGER(config_look_align_end_of_lines) == CONFIG_LOOK_ALIGN_END_OF_LINES_BUFFER))
+    {
+        return length_time;
+    }
+    
     /* length of buffer name (when many buffers are merged) */
     if (buffer->mixed_lines)
     {
@@ -116,9 +130,18 @@ gui_line_get_align (struct t_gui_buffer *buffer, struct t_gui_line *line,
     else
         length_buffer = 0;
     
+    /* return immediately if alignment for end of lines is "prefix" */
+    if (!first_line
+        && (CONFIG_INTEGER(config_look_align_end_of_lines) == CONFIG_LOOK_ALIGN_END_OF_LINES_PREFIX))
+    {
+        return length_time + length_buffer;
+    }
+    
     if (CONFIG_INTEGER(config_look_prefix_align) == CONFIG_LOOK_PREFIX_ALIGN_NONE)
+    {
         return length_time + length_buffer + line->data->prefix_length
             + ((line->data->prefix_length > 0) ? 1 : 0);
+    }
     
     length_suffix = 0;
     if (with_suffix)
