@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_GUI_LINE_H
 #define __WEECHAT_GUI_LINE_H 1
 
@@ -69,7 +69,7 @@ extern struct t_gui_lines *gui_lines_alloc ();
 extern void gui_lines_free (struct t_gui_lines *lines);
 extern int gui_line_get_align (struct t_gui_buffer *buffer,
                                struct t_gui_line *line,
-                               int with_suffix);
+                               int with_suffix, int first_line);
 extern int gui_line_is_displayed (struct t_gui_line *line);
 extern struct t_gui_line *gui_line_get_first_displayed (struct t_gui_buffer *buffer);
 extern struct t_gui_line *gui_line_get_last_displayed (struct t_gui_buffer *buffer);
@@ -106,4 +106,4 @@ extern int gui_line_add_to_infolist (struct t_infolist *infolist,
                                      struct t_gui_line *line);
 extern void gui_lines_print_log (struct t_gui_lines *lines);
 
-#endif /* gui-line.h */
+#endif /* __WEECHAT_GUI_LINE_H */
