@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * alias-info.c: info and infolist hooks for alias plugin
  */
 
-
 #include <stdlib.h>
 
 #include "../weechat-plugin.h"
@@ -97,6 +97,6 @@ alias_info_init ()
     /* alias infolist hooks */
     weechat_hook_infolist ("alias", N_("list of aliases"),
                            N_("alias pointer (optional)"),
-                           N_("alias name (can start or end with \"*\" as joker) (optional)"),
+                           N_("alias name (can start or end with \"*\" as wildcard) (optional)"),
                            &alias_info_get_infolist_cb, NULL);
 }
