@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * fifo.c: fifo plugin for WeeChat: remote control with FIFO pipe
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -38,7 +38,7 @@
 
 WEECHAT_PLUGIN_NAME(FIFO_PLUGIN_NAME);
 WEECHAT_PLUGIN_DESCRIPTION("Fifo plugin for WeeChat");
-WEECHAT_PLUGIN_AUTHOR("FlashCode <flashcode@flashtux.org>");
+WEECHAT_PLUGIN_AUTHOR("Sebastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
 
@@ -58,6 +58,9 @@ char *fifo_filename;
 char *fifo_unterminated = NULL;
 
 
+int fifo_read();
+
+
 /*
  * fifo_remove_old_pipes: remove old fifo pipes in directory
  */
@@ -111,18 +114,14 @@ fifo_remove_old_pipes ()
 
 /*
  * fifo_create: create FIFO pipe for remote control
- *              return: 1 if ok
- *                      0 if error
  */
 
-int
+void
 fifo_create ()
 {
-    int rc, filename_length;
+    int filename_length;
     const char *fifo_option, *weechat_home;
     
-    rc = 0;
-    
     fifo_option = weechat_config_get_plugin ("fifo");
     if (!fifo_option)
     {
@@ -166,7 +165,8 @@ fifo_create ()
                                         _("%s: pipe opened"),
                                         FIFO_PLUGIN_NAME);
                     }
-                    rc = 1;
+                    fifo_fd_hook = weechat_hook_fd (fifo_fd, 1, 0, 0,
+                                                    &fifo_read, NULL);
                 }
                 else
                     weechat_printf (NULL,
@@ -183,8 +183,6 @@ fifo_create ()
                                 fifo_filename);
         }
     }
-    
-    return rc;
 }
 
 /*
@@ -438,9 +436,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     
     fifo_quiet = 1;
     
-    if (fifo_create ())
-        fifo_fd_hook = weechat_hook_fd (fifo_fd, 1, 0, 0,
-                                        &fifo_read, NULL);
+    fifo_create ();
     
     weechat_hook_config ("plugins.var.fifo.fifo", &fifo_config_cb, NULL);
     
