@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-bar-item.c: bar items for IRC plugin
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -206,7 +206,7 @@ irc_bar_item_buffer_name (void *data, struct t_gui_bar_item *item,
                 snprintf (buf_name, sizeof (buf_name), "%s%s[%s%s%s]",
                           _("server"),
                           IRC_COLOR_BAR_DELIM,
-                          IRC_COLOR_STATUS_NAME,
+                          (server && server->ssl_connected) ? IRC_COLOR_STATUS_NAME_SSL : IRC_COLOR_STATUS_NAME,
                           server->name,
                           IRC_COLOR_BAR_DELIM);
             }
@@ -220,11 +220,11 @@ irc_bar_item_buffer_name (void *data, struct t_gui_bar_item *item,
                               "%s%s%s%s%s%s%s%s%s%s",
                               (part_from_channel) ? IRC_COLOR_BAR_DELIM : "",
                               (part_from_channel) ? "(" : "",
-                              IRC_COLOR_STATUS_NAME,
+                              (server && server->ssl_connected) ? IRC_COLOR_STATUS_NAME_SSL : IRC_COLOR_STATUS_NAME,
                               (display_server) ? server->name : "",
                               (display_server) ? IRC_COLOR_BAR_DELIM : "",
                               (display_server) ? "/" : "",
-                              IRC_COLOR_STATUS_NAME,
+                              (server && server->ssl_connected) ? IRC_COLOR_STATUS_NAME_SSL : IRC_COLOR_STATUS_NAME,
                               channel->name,
                               (part_from_channel) ? IRC_COLOR_BAR_DELIM : "",
                               (part_from_channel) ? ")" : "");
@@ -267,7 +267,7 @@ irc_bar_item_buffer_name (void *data, struct t_gui_bar_item *item,
         }
         
         snprintf (buf, sizeof (buf), "%s%s%s",
-                  IRC_COLOR_STATUS_NAME,
+                  (server && server->ssl_connected) ? IRC_COLOR_STATUS_NAME_SSL : IRC_COLOR_STATUS_NAME,
                   buf_name,
                   modes);
         return strdup (buf);
@@ -365,7 +365,7 @@ char *
 irc_bar_item_lag (void *data, struct t_gui_bar_item *item,
                   struct t_gui_window *window)
 {
-    char buf[32];
+    char buf[128];
     struct t_gui_buffer *buffer;
     struct t_irc_server *server;
     
@@ -380,11 +380,14 @@ irc_bar_item_lag (void *data, struct t_gui_bar_item *item,
         irc_buffer_get_server_and_channel (buffer, &server, NULL);
         
         if (server
-            && (server->lag >= weechat_config_integer (irc_config_network_lag_min_show) * 1000))
+            && (server->lag >= weechat_config_integer (irc_config_network_lag_min_show)))
         {
             snprintf (buf, sizeof (buf),
-                      "%s: %.1f",
+                      ((server->lag_check_time.tv_sec == 0) || (server->lag < 1000)) ?
+                      "%s: %s%.3f" : "%s: %s%.0f",
                       _("Lag"),
+                      (server->lag_check_time.tv_sec == 0) ?
+                      IRC_COLOR_ITEM_LAG_FINISHED : IRC_COLOR_ITEM_LAG_COUNTING,
                       ((float)(server->lag)) / 1000);
             return strdup (buf);
         }
@@ -405,7 +408,7 @@ irc_bar_item_input_prompt (void *data, struct t_gui_bar_item *item,
     struct t_irc_server *server;
     struct t_irc_channel *channel;
     struct t_irc_nick *ptr_nick;
-    char *buf, prefix[2], str_prefix_color[64], str_prefix[64];
+    char *buf, prefix[2], str_prefix[64];
     int length, prefix_color;
     
     /* make C compiler happy */
@@ -434,15 +437,12 @@ irc_bar_item_input_prompt (void *data, struct t_gui_bar_item *item,
             {
                 prefix[0] = '\0';
                 prefix[1] = '\0';
-                irc_nick_get_gui_infos (ptr_nick, &prefix[0], &prefix_color,
-                                        NULL, NULL);
+                irc_nick_get_gui_infos (server, ptr_nick,
+                                        &prefix[0], &prefix_color, NULL, NULL);
                 if (prefix[0] != ' ')
                 {
-                    snprintf (str_prefix_color, sizeof (str_prefix_color),
-                              "weechat.color.nicklist_prefix%d",
-                              prefix_color);
                     snprintf (str_prefix, sizeof (str_prefix), "%s%s",
-                              weechat_color(weechat_config_string(weechat_config_get(str_prefix_color))),
+                              weechat_color (weechat_config_string (weechat_config_get (irc_nick_get_prefix_color_name (prefix_color)))),
                               prefix);
                 }
             }
