@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_IRC_BUFFER_H
 #define __WEECHAT_IRC_BUFFER_H 1
 
@@ -55,4 +55,4 @@ extern char *irc_buffer_build_name (const char *server, const char *channel);
 extern int irc_buffer_close_cb (void *data, struct t_gui_buffer *buffer);
 extern struct t_gui_buffer *irc_buffer_search_first_for_all_servers ();
 
-#endif /* irc-buffer.h */
+#endif /* __WEECHAT_IRC_BUFFER_H */
