@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-channel.c: channel and private chat management for IRC plugin
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -31,6 +31,7 @@
 #include "irc.h"
 #include "irc-channel.h"
 #include "irc-buffer.h"
+#include "irc-color.h"
 #include "irc-command.h"
 #include "irc-config.h"
 #include "irc-nick.h"
@@ -195,6 +196,8 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
         weechat_buffer_set (new_buffer, "localvar_set_nick", server->nick);
         weechat_buffer_set (new_buffer, "localvar_set_server", server->name);
         weechat_buffer_set (new_buffer, "localvar_set_channel", channel_name);
+        if (server->is_away && server->away_message)
+            weechat_buffer_set (new_buffer, "localvar_set_away", server->away_message);
         weechat_hook_signal_send ("logger_backlog",
                                   WEECHAT_HOOK_SIGNAL_POINTER, new_buffer);
         if (weechat_config_boolean (irc_config_network_send_unknown_commands))
@@ -244,6 +247,7 @@ irc_channel_new (struct t_irc_server *server, int channel_type,
     new_channel->key = NULL;
     new_channel->checking_away = 0;
     new_channel->away_message = NULL;
+    new_channel->has_quit_server = 0;
     new_channel->cycle = 0;
     new_channel->display_creation_date = 0;
     new_channel->nick_completion_reset = 0;
@@ -679,6 +683,47 @@ irc_channel_autorejoin_cb (void *data, int remaining_calls)
     return WEECHAT_RC_OK;
 }
 
+/*
+ * irc_channel_display_nick_back_in_pv: display a message in pv buffer if nick
+ *                                      is back and if private has flag
+ *                                      "has_quit_server"
+ */
+
+void
+irc_channel_display_nick_back_in_pv (struct t_irc_server *server,
+                                     struct t_irc_nick *nick,
+                                     const char *nickname)
+{
+    struct t_irc_channel *ptr_channel;
+    
+    if (!server || (!nick && !nickname))
+        return;
+    
+    for (ptr_channel = server->channels; ptr_channel;
+         ptr_channel = ptr_channel->next_channel)
+    {
+        if ((ptr_channel->type == IRC_CHANNEL_TYPE_PRIVATE)
+            && ptr_channel->has_quit_server
+            && (strcmp (ptr_channel->name, (nick) ? nick->name : nickname) == 0))
+        {
+            if (weechat_config_boolean (irc_config_look_display_pv_back))
+            {
+                weechat_printf (ptr_channel->buffer,
+                                _("%s%s%s %s(%s%s%s)%s is back on server"),
+                                weechat_prefix ("join"),
+                                IRC_COLOR_NICK_IN_SERVER_MESSAGE(nick),
+                                (nick) ? nick->name : nickname,
+                                IRC_COLOR_CHAT_DELIMITERS,
+                                IRC_COLOR_CHAT_HOST,
+                                (nick) ? nick->host : "",
+                                IRC_COLOR_CHAT_DELIMITERS,
+                                IRC_COLOR_MESSAGE_JOIN);
+            }
+            ptr_channel->has_quit_server = 0;
+        }
+    }
+}
+
 /*
  * irc_channel_free: free a channel and remove it from channels list
  */
@@ -714,7 +759,7 @@ irc_channel_free (struct t_irc_server *server, struct t_irc_channel *channel)
         free (channel->modes);
     if (channel->key)
         free (channel->key);
-    irc_nick_free_all (channel);
+    irc_nick_free_all (server, channel);
     if (channel->away_message)
         free (channel->away_message);
     if (channel->pv_remote_nick_color)
@@ -799,6 +844,8 @@ irc_channel_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "away_message", channel->away_message))
         return 0;
+    if (!weechat_infolist_new_var_integer (ptr_item, "has_quit_server", channel->has_quit_server))
+        return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "cycle", channel->cycle))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "display_creation_date", channel->display_creation_date))
@@ -867,6 +914,7 @@ irc_channel_print_log (struct t_irc_channel *channel)
     weechat_log_printf ("       key. . . . . . . . . . . : '%s'",  channel->key);
     weechat_log_printf ("       checking_away. . . . . . : %d",    channel->checking_away);
     weechat_log_printf ("       away_message . . . . . . : '%s'",  channel->away_message);
+    weechat_log_printf ("       has_quit_server. . . . . : %d",    channel->has_quit_server);
     weechat_log_printf ("       cycle. . . . . . . . . . : %d",    channel->cycle);
     weechat_log_printf ("       display_creation_date. . : %d",    channel->display_creation_date);
     weechat_log_printf ("       nick_completion_reset. . : %d",    channel->nick_completion_reset);
