@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_IRC_CHANNEL_H
 #define __WEECHAT_IRC_CHANNEL_H 1
 
@@ -49,6 +49,8 @@ struct t_irc_channel
     char *key;                         /* channel key (NULL if no key set)  */
     int checking_away;                 /* = 1 if checking away with WHO cmd */
     char *away_message;                /* to display away only once in pv   */
+    int has_quit_server;               /* =1 if nick has quit (pv only), to */
+                                       /* display message when he's back    */
     int cycle;                         /* currently cycling (/part + /join) */
     int display_creation_date;         /* 1 for displaying creation date    */
     int nick_completion_reset;         /* 1 for resetting nick completion   */
@@ -112,8 +114,11 @@ extern void irc_channel_nick_speaking_time_rename (struct t_irc_channel *channel
 extern void irc_channel_rejoin (struct t_irc_server *server,
                                 struct t_irc_channel *channel);
 extern int irc_channel_autorejoin_cb (void *data, int remaining_calls);
+extern void irc_channel_display_nick_back_in_pv (struct t_irc_server *server,
+                                                 struct t_irc_nick *nick,
+                                                 const char *nickname);
 extern int irc_channel_add_to_infolist (struct t_infolist *infolist,
                                         struct t_irc_channel *channel);
 extern void irc_channel_print_log (struct t_irc_channel *channel);
 
-#endif /* irc-channel.h */
+#endif /* __WEECHAT_IRC_CHANNEL_H */
