@@ -1,30 +1,31 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-config.c: IRC configuration options (file irc.conf)
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
+#include <time.h>
 #include <limits.h>
 #include <pwd.h>
 
@@ -60,7 +61,12 @@ struct t_config_option *irc_config_look_display_away;
 struct t_config_option *irc_config_look_display_ctcp_blocked;
 struct t_config_option *irc_config_look_display_ctcp_reply;
 struct t_config_option *irc_config_look_display_ctcp_unknown;
+struct t_config_option *irc_config_look_display_host_join;
+struct t_config_option *irc_config_look_display_host_join_local;
+struct t_config_option *irc_config_look_display_host_quit;
 struct t_config_option *irc_config_look_display_old_topic;
+struct t_config_option *irc_config_look_display_pv_away_once;
+struct t_config_option *irc_config_look_display_pv_back;
 struct t_config_option *irc_config_look_item_channel_modes;
 struct t_config_option *irc_config_look_item_channel_modes_hide_key;
 struct t_config_option *irc_config_look_item_nick_modes;
@@ -69,10 +75,10 @@ struct t_config_option *irc_config_look_hide_nickserv_pwd;
 struct t_config_option *irc_config_look_highlight_tags;
 struct t_config_option *irc_config_look_item_display_server;
 struct t_config_option *irc_config_look_msgbuffer_fallback;
+struct t_config_option *irc_config_look_nick_color_stop_chars;
 struct t_config_option *irc_config_look_notice_as_pv;
 struct t_config_option *irc_config_look_part_closes_buffer;
 struct t_config_option *irc_config_look_raw_messages;
-struct t_config_option *irc_config_look_show_away_once;
 struct t_config_option *irc_config_look_smart_filter;
 struct t_config_option *irc_config_look_smart_filter_delay;
 struct t_config_option *irc_config_look_smart_filter_join;
@@ -83,13 +89,22 @@ struct t_config_option *irc_config_look_topic_strip_colors;
 
 struct t_config_option *irc_config_color_message_join;
 struct t_config_option *irc_config_color_message_quit;
+struct t_config_option *irc_config_color_nick_prefix_op;
+struct t_config_option *irc_config_color_nick_prefix_halfop;
+struct t_config_option *irc_config_color_nick_prefix_voice;
+struct t_config_option *irc_config_color_nick_prefix_user;
 struct t_config_option *irc_config_color_notice;
 struct t_config_option *irc_config_color_input_nick;
 struct t_config_option *irc_config_color_item_away;
 struct t_config_option *irc_config_color_item_channel_modes;
+struct t_config_option *irc_config_color_item_lag_counting;
+struct t_config_option *irc_config_color_item_lag_finished;
+struct t_config_option *irc_config_color_reason_quit;
 
 /* IRC config, network section */
 
+struct t_config_option *irc_config_network_autoreconnect_delay_growing;
+struct t_config_option *irc_config_network_autoreconnect_delay_max;
 struct t_config_option *irc_config_network_connection_timeout;
 struct t_config_option *irc_config_network_default_msg_part;
 struct t_config_option *irc_config_network_default_msg_quit;
@@ -98,6 +113,7 @@ struct t_config_option *irc_config_network_away_check_max_nicks;
 struct t_config_option *irc_config_network_lag_check;
 struct t_config_option *irc_config_network_lag_min_show;
 struct t_config_option *irc_config_network_lag_disconnect;
+struct t_config_option *irc_config_network_lag_refresh_interval;
 struct t_config_option *irc_config_network_anti_flood[2];
 struct t_config_option *irc_config_network_colors_receive;
 struct t_config_option *irc_config_network_colors_send;
@@ -138,24 +154,17 @@ irc_config_get_server_from_option_name (const char *name)
 }
 
 /*
- * irc_config_change_look_color_nicks_number: called when the
- *                                            "weechat.look.color_nicks_number"
- *                                            option is changed
+ * irc_config_compute_nick_colors: compute nick colors for all servers and
+ *                                 channels
  */
 
-int
-irc_config_change_look_color_nicks_number (void *data, const char *option,
-                                           const char *value)
+void
+irc_config_compute_nick_colors ()
 {
     struct t_irc_server *ptr_server;
     struct t_irc_channel *ptr_channel;
     struct t_irc_nick *ptr_nick;
     
-    /* make C compiler happy */
-    (void) data;
-    (void) option;
-    (void) value;
-    
     for (ptr_server = irc_servers; ptr_server;
          ptr_server = ptr_server->next_server)
     {
@@ -169,6 +178,24 @@ irc_config_change_look_color_nicks_number (void *data, const char *option,
             }
         }
     }
+}
+
+/*
+ * irc_config_change_look_color_nicks_number: called when the
+ *                                            "weechat.look.color_nicks_number"
+ *                                            option is changed
+ */
+
+int
+irc_config_change_look_color_nicks_number (void *data, const char *option,
+                                           const char *value)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    (void) value;
+    
+    irc_config_compute_nick_colors ();
     
     return WEECHAT_RC_OK;
 }
@@ -322,6 +349,22 @@ irc_config_change_look_highlight_tags (void *data,
     }
 }
 
+/*
+ * irc_config_change_look_nick_color_stop_chars: called when the "nick color
+ *                                               stop chars" option is changed
+ */
+
+void
+irc_config_change_look_nick_color_stop_chars (void *data,
+                                              struct t_config_option *option)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    
+    irc_config_compute_nick_colors ();
+}
+
 /*
  * irc_config_change_look_item_display_server: called when the
  *                                             "item_display_server" option is
@@ -389,13 +432,13 @@ irc_config_change_color_item_away (void *data,
 }
 
 /*
- * irc_config_change_color_item_channel_modes: called when the color of channel
- *                                             modes is changed
+ * irc_config_change_color_item_buffer_name: called when the color of buffer
+ *                                           name is changed
  */
 
 void
-irc_config_change_color_item_channel_modes (void *data,
-                                            struct t_config_option *option)
+irc_config_change_color_item_buffer_name (void *data,
+                                          struct t_config_option *option)
 {
     /* make C compiler happy */
     (void) data;
@@ -404,6 +447,39 @@ irc_config_change_color_item_channel_modes (void *data,
     weechat_bar_item_update ("buffer_name");
 }
 
+/*
+ * irc_config_change_color_item_lag: called when the color of lag item is
+ *                                   changed
+ */
+
+void
+irc_config_change_color_item_lag (void *data,
+                                  struct t_config_option *option)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    
+    weechat_bar_item_update ("lag");
+}
+
+/*
+ * irc_config_change_color_nick_prefix: called when the color of a nick prefix
+ *                                      is changed
+ */
+
+void
+irc_config_change_color_nick_prefix (void *data,
+                                     struct t_config_option *option)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    
+    weechat_bar_item_update ("input_prompt");
+    weechat_bar_item_update ("nicklist");
+}
+
 /*
  * irc_config_change_network_away_check: called when away check is changed
  */
@@ -435,6 +511,47 @@ irc_config_change_network_away_check (void *data,
     }
 }
 
+/*
+ * irc_config_change_network_lag_check: called when lag check is changed
+ */
+
+void
+irc_config_change_network_lag_check (void *data,
+                                     struct t_config_option *option)
+{
+    time_t time_next_check;
+    struct t_irc_server *ptr_server;
+    
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    
+    time_next_check = (weechat_config_integer (irc_config_network_lag_check) > 0) ?
+        time (NULL) : 0;
+    
+    for (ptr_server = irc_servers; ptr_server;
+         ptr_server = ptr_server->next_server)
+    {
+        if (ptr_server->is_connected)
+            ptr_server->lag_next_check = time_next_check;
+    }
+}
+
+/*
+ * irc_config_change_network_lag_min_show: called when lag min show is changed
+ */
+
+void
+irc_config_change_network_lag_min_show (void *data,
+                                        struct t_config_option *option)
+{
+    /* make C compiler happy */
+    (void) data;
+    (void) option;
+    
+    weechat_bar_item_update ("lag");
+}
+
 /*
  * irc_config_change_network_send_unknown_commands: called when "send_unknown_commands"
  *                                                  is changed
@@ -1055,7 +1172,7 @@ irc_config_server_new_option (struct t_config_file *config_file,
                 config_file, section,
                 option_name, "integer",
                 N_("delay (in seconds) before trying again to reconnect to server"),
-                NULL, 0, 65535,
+                NULL, 1, 65535,
                 default_value, value,
                 null_value_allowed,
                 NULL, NULL,
@@ -1301,12 +1418,12 @@ void
 irc_config_server_create_default_options (struct t_config_section *section)
 {
     int i, length;
-    char *nicks, *username, *realname, *pos, *default_value;
+    char *nicks, *username, *realname, *default_value;
     struct passwd *my_passwd;
     
     nicks = NULL;
     username = NULL;
-    realname = NULL;
+    realname = strdup ("");
     
     /* Get the user's name from /etc/passwd */
     if ((my_passwd = getpwuid (geteuid ())) != NULL)
@@ -1323,25 +1440,12 @@ irc_config_server_create_default_options (struct t_config_section *section)
                       my_passwd->pw_name);
         }
         username = strdup (my_passwd->pw_name);
-        if ((!my_passwd->pw_gecos)
-            || (my_passwd->pw_gecos[0] == '\0')
-            || (my_passwd->pw_gecos[0] == ',')
-            || (my_passwd->pw_gecos[0] == ' '))
-            realname = strdup (my_passwd->pw_name);
-        else
-        {
-            realname = strdup (my_passwd->pw_gecos);
-            pos = strchr (realname, ',');
-            if (pos)
-                pos[0] = '\0';
-        }
     }
     else
     {
         /* default values if /etc/passwd can't be read */
         nicks = strdup (IRC_SERVER_DEFAULT_NICKS);
         username = strdup ("weechat");
-        realname = strdup ("weechat");
     }
     
     for (i = 0; i < IRC_SERVER_NUM_OPTIONS; i++)
@@ -1478,12 +1582,41 @@ irc_config_init ()
         N_("display CTCP message even if it is unknown CTCP"),
         NULL, 0, 0, "on", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
+    irc_config_look_display_host_join = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "display_host_join", "boolean",
+        N_("display host in join messages"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
+    irc_config_look_display_host_join_local = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "display_host_join_local", "boolean",
+        N_("display host in join messages from local client"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
+    irc_config_look_display_host_quit = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "display_host_quit", "boolean",
+        N_("display host in part/quit messages"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
     irc_config_look_display_old_topic = weechat_config_new_option (
         irc_config_file, ptr_section,
         "display_old_topic", "boolean",
         N_("display old topic when channel topic is changed"),
         NULL, 0, 0, "on", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
+    irc_config_look_display_pv_away_once = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "display_pv_away_once", "boolean",
+        N_("display remote away message only once in private"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+    irc_config_look_display_pv_back = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "display_pv_back", "boolean",
+        N_("display a message in private when user is back (after quit on "
+           "server)"),
+        NULL, 0, 0, "on", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     irc_config_look_item_channel_modes = weechat_config_new_option (
         irc_config_file, ptr_section,
         "item_channel_modes", "boolean",
@@ -1536,17 +1669,32 @@ irc_config_init ()
            "private and that private buffer is not found"),
         "current|server", 0, 0, "current", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
+    irc_config_look_nick_color_stop_chars = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "nick_color_stop_chars", "string",
+        N_("chars used to stop in nick when computing color with letters of "
+           "nick (at least one char outside this list must be in string before "
+           "stopping) (example: nick \"|nick|away\" with \"|\" in chars will "
+           "return color of nick \"|nick\")"),
+        NULL, 0, 0, "_|[", NULL, 0, NULL, NULL,
+        &irc_config_change_look_nick_color_stop_chars, NULL, NULL, NULL);
+    irc_config_look_notice_as_pv = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "notice_as_pv", "integer",
+        N_("display notices as private messages (if auto, use private buffer "
+           "if found)"),
+        "auto|never|always", 0, 0, "auto", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+    irc_config_look_part_closes_buffer = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "part_closes_buffer", "boolean",
+        N_("close buffer when /part is issued on a channel"),
+        NULL, 0, 0, "off", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     irc_config_look_raw_messages = weechat_config_new_option (
         irc_config_file, ptr_section,
         "raw_messages", "integer",
         N_("number of IRC raw messages to save in memory when raw data buffer "
            "is closed (messages will be displayed when opening raw data buffer)"),
         NULL, 0, 65535, "256", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
-    irc_config_look_show_away_once = weechat_config_new_option (
-        irc_config_file, ptr_section,
-        "show_away_once", "boolean",
-        N_("show remote away message only once in private"),
-        NULL, 0, 0, "on", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     irc_config_look_smart_filter = weechat_config_new_option (
         irc_config_file, ptr_section,
         "smart_filter", "boolean",
@@ -1569,17 +1717,6 @@ irc_config_init ()
         "smart_filter_quit", "boolean",
         N_("enable smart filter for \"part\" and \"quit\" messages"),
         NULL, 0, 0, "on", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
-    irc_config_look_notice_as_pv = weechat_config_new_option (
-        irc_config_file, ptr_section,
-        "notice_as_pv", "integer",
-        N_("display notices as private messages (if auto, use private buffer "
-           "if found)"),
-        "auto|never|always", 0, 0, "auto", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
-    irc_config_look_part_closes_buffer = weechat_config_new_option (
-        irc_config_file, ptr_section,
-        "part_closes_buffer", "boolean",
-        N_("close buffer when /part is issued on a channel"),
-        NULL, 0, 0, "off", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     irc_config_look_topic_strip_colors = weechat_config_new_option (
         irc_config_file, ptr_section,
         "topic_strip_colors", "boolean",
@@ -1611,6 +1748,30 @@ irc_config_init ()
         N_("color for text in part/quit messages"),
         NULL, -1, 0, "red", NULL, 0, NULL, NULL,
         NULL, NULL, NULL, NULL);
+    irc_config_color_nick_prefix_op = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "nick_prefix_op", "color",
+        N_("color for prefix of nick which is op/admin/owner on channel"),
+        NULL, -1, 0, "lightgreen", NULL, 0, NULL, NULL,
+        &irc_config_change_color_nick_prefix, NULL, NULL, NULL);
+    irc_config_color_nick_prefix_halfop = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "nick_prefix_halfop", "color",
+        N_("color for prefix of nick which is halfop on channel"),
+        NULL, -1, 0, "lightmagenta", NULL, 0, NULL, NULL,
+        &irc_config_change_color_nick_prefix, NULL, NULL, NULL);
+    irc_config_color_nick_prefix_voice = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "nick_prefix_voice", "color",
+        N_("color for prefix of nick which has voice on channel"),
+        NULL, -1, 0, "yellow", NULL, 0, NULL, NULL,
+        &irc_config_change_color_nick_prefix, NULL, NULL, NULL);
+    irc_config_color_nick_prefix_user = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "nick_prefix_user", "color",
+        N_("color for prefix of nick which is user on channel"),
+        NULL, -1, 0, "blue", NULL, 0, NULL, NULL,
+        &irc_config_change_color_nick_prefix, NULL, NULL, NULL);
     irc_config_color_notice = weechat_config_new_option (
         irc_config_file, ptr_section,
         "notice", "color",
@@ -1634,7 +1795,26 @@ irc_config_init ()
         "item_channel_modes", "color",
         N_("color for channel modes, near channel name"),
         NULL, -1, 0, "default", NULL, 0, NULL, NULL,
-        &irc_config_change_color_item_channel_modes, NULL, NULL, NULL);
+        &irc_config_change_color_item_buffer_name, NULL, NULL, NULL);
+    irc_config_color_item_lag_counting = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "item_lag_counting", "color",
+        N_("color for lag indicator, when counting (pong not received from "
+           "server, lag is increasing)"),
+        NULL, -1, 0, "default", NULL, 0, NULL, NULL,
+        &irc_config_change_color_item_lag, NULL, NULL, NULL);
+    irc_config_color_item_lag_finished = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "item_lag_finished", "color",
+        N_("color for lag indicator, when pong has been received from server"),
+        NULL, -1, 0, "yellow", NULL, 0, NULL, NULL,
+        &irc_config_change_color_item_lag, NULL, NULL, NULL);
+    irc_config_color_reason_quit = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "reason_quit", "color",
+        N_("color for reason in part/quit messages"),
+        NULL, -1, 0, "default", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
     
     /* network */
     ptr_section = weechat_config_new_section (irc_config_file, "network",
@@ -1648,6 +1828,19 @@ irc_config_init ()
         return 0;
     }
     
+    irc_config_network_autoreconnect_delay_growing = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "autoreconnect_delay_growing", "integer",
+        N_("growing factor for autoreconnect delay to server (1 = always same "
+           "delay, 2 = delay*2 for each retry, ..)"),
+        NULL, 1, 100, "2", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
+    irc_config_network_autoreconnect_delay_max = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "autoreconnect_delay_max", "integer",
+        N_("maximum autoreconnect delay to server (in seconds, 0 = no maximum)"),
+        NULL, 0, 3600 * 24, "1800", NULL, 0, NULL, NULL,
+        NULL, NULL, NULL, NULL);
     irc_config_network_connection_timeout = weechat_config_new_option (
         irc_config_file, ptr_section,
         "connection_timeout", "integer",
@@ -1673,32 +1866,40 @@ irc_config_init ()
         "away_check", "integer",
         N_("interval between two checks for away (in minutes, 0 = never "
            "check)"),
-        NULL, 0, INT_MAX, "0", NULL, 0, NULL, NULL,
+        NULL, 0, 60 * 24 * 7, "0", NULL, 0, NULL, NULL,
         &irc_config_change_network_away_check, NULL, NULL, NULL);
     irc_config_network_away_check_max_nicks = weechat_config_new_option (
         irc_config_file, ptr_section,
         "away_check_max_nicks", "integer",
         N_("do not check away nicks on channels with high number of nicks "
            "(0 = unlimited)"),
-        NULL, 0, INT_MAX, "25", NULL, 0, NULL, NULL,
+        NULL, 0, 1000000, "25", NULL, 0, NULL, NULL,
         &irc_config_change_network_away_check, NULL, NULL, NULL);
     irc_config_network_lag_check = weechat_config_new_option (
         irc_config_file, ptr_section,
         "lag_check", "integer",
         N_("interval between two checks for lag (in seconds, 0 = never "
            "check)"),
-        NULL, 0, INT_MAX, "60", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, 0, 3600 * 24 * 7, "60", NULL, 0, NULL, NULL,
+        &irc_config_change_network_lag_check, NULL, NULL, NULL);
     irc_config_network_lag_min_show = weechat_config_new_option (
         irc_config_file, ptr_section,
         "lag_min_show", "integer",
-        N_("minimum lag to show (in seconds)"),
-        NULL, 0, INT_MAX, "1", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+        N_("minimum lag to show (in milliseconds)"),
+        NULL, 0, 1000 * 3600 * 24, "500", NULL, 0, NULL, NULL,
+        &irc_config_change_network_lag_min_show, NULL, NULL, NULL);
     irc_config_network_lag_disconnect = weechat_config_new_option (
         irc_config_file, ptr_section,
         "lag_disconnect", "integer",
         N_("disconnect after important lag (in minutes, 0 = never "
            "disconnect)"),
-        NULL, 0, INT_MAX, "0", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+        NULL, 0, 60 * 24 * 7, "0", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
+    irc_config_network_lag_refresh_interval = weechat_config_new_option (
+        irc_config_file, ptr_section,
+        "lag_refresh_interval", "integer",
+        N_("interval between two refreshs of lag item, when lag is increasing "
+           "(in seconds)"),
+        NULL, 1, 3600, "1", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
     irc_config_network_anti_flood[0] = weechat_config_new_option (
         irc_config_file, ptr_section,
         "anti_flood_prio_high", "integer",
