@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_IRC_CONFIG_H
 #define __WEECHAT_IRC_CONFIG_H 1
 
@@ -80,7 +80,12 @@ extern struct t_config_option *irc_config_look_display_away;
 extern struct t_config_option *irc_config_look_display_ctcp_blocked;
 extern struct t_config_option *irc_config_look_display_ctcp_reply;
 extern struct t_config_option *irc_config_look_display_ctcp_unknown;
+extern struct t_config_option *irc_config_look_display_host_join;
+extern struct t_config_option *irc_config_look_display_host_join_local;
+extern struct t_config_option *irc_config_look_display_host_quit;
 extern struct t_config_option *irc_config_look_display_old_topic;
+extern struct t_config_option *irc_config_look_display_pv_away_once;
+extern struct t_config_option *irc_config_look_display_pv_back;
 extern struct t_config_option *irc_config_look_item_channel_modes;
 extern struct t_config_option *irc_config_look_item_channel_modes_hide_key;
 extern struct t_config_option *irc_config_look_item_nick_modes;
@@ -89,10 +94,10 @@ extern struct t_config_option *irc_config_look_hide_nickserv_pwd;
 extern struct t_config_option *irc_config_look_highlight_tags;
 extern struct t_config_option *irc_config_look_item_display_server;
 extern struct t_config_option *irc_config_look_msgbuffer_fallback;
+extern struct t_config_option *irc_config_look_nick_color_stop_chars;
 extern struct t_config_option *irc_config_look_notice_as_pv;
 extern struct t_config_option *irc_config_look_part_closes_buffer;
 extern struct t_config_option *irc_config_look_raw_messages;
-extern struct t_config_option *irc_config_look_show_away_once;
 extern struct t_config_option *irc_config_look_smart_filter;
 extern struct t_config_option *irc_config_look_smart_filter_delay;
 extern struct t_config_option *irc_config_look_smart_filter_join;
@@ -101,11 +106,20 @@ extern struct t_config_option *irc_config_look_topic_strip_colors;
 
 extern struct t_config_option *irc_config_color_message_join;
 extern struct t_config_option *irc_config_color_message_quit;
+extern struct t_config_option *irc_config_color_nick_prefix_op;
+extern struct t_config_option *irc_config_color_nick_prefix_halfop;
+extern struct t_config_option *irc_config_color_nick_prefix_voice;
+extern struct t_config_option *irc_config_color_nick_prefix_user;
 extern struct t_config_option *irc_config_color_notice;
 extern struct t_config_option *irc_config_color_input_nick;
 extern struct t_config_option *irc_config_color_item_away;
 extern struct t_config_option *irc_config_color_item_channel_modes;
+extern struct t_config_option *irc_config_color_item_lag_counting;
+extern struct t_config_option *irc_config_color_item_lag_finished;
+extern struct t_config_option *irc_config_color_reason_quit;
 
+extern struct t_config_option *irc_config_network_autoreconnect_delay_growing;
+extern struct t_config_option *irc_config_network_autoreconnect_delay_max;
 extern struct t_config_option *irc_config_network_connection_timeout;
 extern struct t_config_option *irc_config_network_default_msg_part;
 extern struct t_config_option *irc_config_network_default_msg_quit;
@@ -114,6 +128,7 @@ extern struct t_config_option *irc_config_network_away_check_max_nicks;
 extern struct t_config_option *irc_config_network_lag_check;
 extern struct t_config_option *irc_config_network_lag_min_show;
 extern struct t_config_option *irc_config_network_lag_disconnect;
+extern struct t_config_option *irc_config_network_lag_refresh_interval;
 extern struct t_config_option *irc_config_network_anti_flood[2];
 extern struct t_config_option *irc_config_network_colors_receive;
 extern struct t_config_option *irc_config_network_colors_send;
@@ -137,4 +152,4 @@ extern int irc_config_read ();
 extern int irc_config_write (int write_temp_servers);
 extern void irc_config_free ();
 
-#endif /* irc-config.h */
+#endif /* __WEECHAT_IRC_CONFIG_H */
