@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-info.c: info and infolist hooks for IRC plugin
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -67,7 +67,7 @@ irc_info_get_info_cb (void *data, const char *info_name,
                       const char *arguments)
 {
     char *pos_comma, *pos_comma2, *server, *channel, *host;
-    const char *nick;
+    const char *nick, *isupport_value;
     static char str_true[2] = "1";
     struct t_irc_server *ptr_server;
     struct t_irc_channel *ptr_channel;
@@ -102,6 +102,10 @@ irc_info_get_info_cb (void *data, const char *info_name,
     {
         return irc_nick_find_color (arguments);
     }
+    else if (weechat_strcasecmp (info_name, "irc_nick_color_name") == 0)
+    {
+        return irc_nick_find_color_name (arguments);
+    }
     else if (weechat_strcasecmp (info_name, "irc_buffer") == 0)
     {
         if (arguments && arguments[0])
@@ -180,6 +184,46 @@ irc_info_get_info_cb (void *data, const char *info_name,
             }
         }
     }
+    else if (weechat_strcasecmp (info_name, "irc_server_isupport") == 0)
+    {
+        isupport_value = NULL;
+        pos_comma = strchr (arguments, ',');
+        if (pos_comma)
+        {
+            server = weechat_strndup (arguments, pos_comma - arguments);
+            if (server)
+            {
+                ptr_server = irc_server_search (server);
+                if (ptr_server)
+                {
+                    isupport_value = irc_server_get_isupport_value (ptr_server,
+                                                                    pos_comma + 1);
+                }
+            }
+        }
+        if (isupport_value)
+            return str_true;
+        return NULL;
+    }
+    else if (weechat_strcasecmp (info_name, "irc_server_isupport_value") == 0)
+    {
+        isupport_value = NULL;
+        pos_comma = strchr (arguments, ',');
+        if (pos_comma)
+        {
+            server = weechat_strndup (arguments, pos_comma - arguments);
+            if (server)
+            {
+                ptr_server = irc_server_search (server);
+                if (ptr_server)
+                {
+                    isupport_value = irc_server_get_isupport_value (ptr_server,
+                                                                    pos_comma + 1);
+                }
+            }
+        }
+        return isupport_value;
+    }
     
     return NULL;
 }
@@ -416,17 +460,26 @@ irc_info_init ()
     weechat_hook_info ("irc_nick_from_host", N_("get nick from IRC host"),
                        N_("IRC host (like `:nick!name@server.com`)"),
                        &irc_info_get_info_cb, NULL);
-    weechat_hook_info ("irc_nick_color", N_("get nick color"),
+    weechat_hook_info ("irc_nick_color", N_("get nick color code"),
+                       N_("nickname"),
+                       &irc_info_get_info_cb, NULL);
+    weechat_hook_info ("irc_nick_color_name", N_("get nick color name"),
                        N_("nickname"),
                        &irc_info_get_info_cb, NULL);
     weechat_hook_info ("irc_buffer", N_("get buffer pointer for an IRC server/channel/nick"),
                        N_("server,channel,nick (channel and nicks are optional)"),
                        &irc_info_get_info_cb, NULL);
+    weechat_hook_info ("irc_server_isupport", N_("1 if server supports this feature (from IRC message 005)"),
+                       N_("server,feature"),
+                       &irc_info_get_info_cb, NULL);
+    weechat_hook_info ("irc_server_isupport_value", N_("value of feature, if supported by server (from IRC message 005)"),
+                       N_("server,feature"),
+                       &irc_info_get_info_cb, NULL);
     
     /* infolist hooks */
     weechat_hook_infolist ("irc_server", N_("list of IRC servers"),
                            N_("server pointer (optional)"),
-                           N_("server name (can start or end with \"*\" as joker) (optional)"),
+                           N_("server name (can start or end with \"*\" as wildcard) (optional)"),
                            &irc_info_get_infolist_cb, NULL);
     weechat_hook_infolist ("irc_channel", N_("list of channels for an IRC server"),
                            N_("channel pointer (optional)"),
