@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-input.c: input data management for IRC buffers
  */
 
-
 #include <stdlib.h>
 #include <string.h>
 
@@ -61,7 +61,8 @@ irc_input_user_message_display (struct t_gui_buffer *buffer, const char *text)
         weechat_printf_tags (buffer,
                              irc_protocol_tags ("privmsg", "no_highlight"),
                              "%s%s",
-                             irc_nick_as_prefix ((ptr_nick) ? ptr_nick : NULL,
+                             irc_nick_as_prefix (ptr_server,
+                                                 (ptr_nick) ? ptr_nick : NULL,
                                                  (ptr_nick) ? NULL : ptr_server->nick,
                                                  IRC_COLOR_CHAT_NICK_SELF),
                              (text_decoded) ? text_decoded : text);
