@@ -1,25 +1,27 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_IRC_MODE_H
 #define __WEECHAT_IRC_MODE_H 1
 
+#define IRC_MODE_NICK_DEFAULT_PREFIXES_LIST "@%+~*&!-"
+
 struct t_irc_server;
 struct t_irc_channel;
 
@@ -27,7 +29,9 @@ extern int irc_mode_channel_set (struct t_irc_server *server,
                                  struct t_irc_channel *channel,
                                  const char *modes);
 extern void irc_mode_user_set (struct t_irc_server *server, const char *modes);
-extern int irc_mode_get_nick_prefix (struct t_irc_server *server, char *mode,
-                                     char prefix);
+extern int irc_mode_get_nick_attr (struct t_irc_server *server, char *mode,
+                                   char prefix);
+extern char irc_mode_get_prefix (struct t_irc_server *server, char mode,
+                                 char default_prefix);
 
-#endif /* irc-mode.h */
+#endif /* __WEECHAT_IRC_MODE_H */
