@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-nick.c: nick management for IRC plugin
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -29,7 +29,9 @@
 #include "../weechat-plugin.h"
 #include "irc.h"
 #include "irc-nick.h"
+#include "irc-color.h"
 #include "irc-config.h"
+#include "irc-mode.h"
 #include "irc-server.h"
 #include "irc-channel.h"
 
@@ -88,14 +90,55 @@ irc_nick_is_nick (const char *string)
 }
 
 /*
- * irc_nick_find_color: find a color for a nick (according to nick letters)
+ * irc_nick_strdup_for_color: duplicate a nick and stop at first char in list
+ *                            (using option irc.look.nick_color_stop_chars)
  */
 
-const char *
-irc_nick_find_color (const char *nickname)
+char *
+irc_nick_strdup_for_color (const char *nickname)
+{
+    int char_size, other_char_seen;
+    char *result, *pos, utf_char[16];
+    
+    result = malloc (strlen (nickname) + 1);
+    pos = result;
+    other_char_seen = 0;
+    while (nickname[0])
+    {
+        char_size = weechat_utf8_char_size (nickname);
+        memcpy (utf_char, nickname, char_size);
+        utf_char[char_size] = '\0';
+        
+        if (strstr (weechat_config_string (irc_config_look_nick_color_stop_chars),
+                    utf_char))
+        {
+            if (other_char_seen)
+            {
+                pos[0] = '\0';
+                return result;
+            }
+        }
+        else
+        {
+            other_char_seen = 1;
+        }
+        memcpy (pos, utf_char, char_size);
+        pos += char_size;
+        
+        nickname += char_size;
+    }
+    pos[0] = '\0';
+    return result;
+}
+
+/*
+ * irc_nick_hash_color: hash a nickname to find color
+ */
+
+int
+irc_nick_hash_color (const char *nickname)
 {
     int color;
-    char color_name[64];
     const char *ptr_nick;
     
     color = 0;
@@ -105,8 +148,25 @@ irc_nick_find_color (const char *nickname)
         color += weechat_utf8_char_int (ptr_nick);
         ptr_nick = weechat_utf8_next_char (ptr_nick);
     }
-    color = (color %
-             weechat_config_integer (weechat_config_get ("weechat.look.color_nicks_number")));
+    return (color %
+            weechat_config_integer (weechat_config_get ("weechat.look.color_nicks_number")));
+}
+
+/*
+ * irc_nick_find_color: find a color code for a nick
+ *                      (according to nick letters)
+ */
+
+const char *
+irc_nick_find_color (const char *nickname)
+{
+    int color;
+    char *nickname2, color_name[64];
+    
+    nickname2 = irc_nick_strdup_for_color (nickname);
+    color = irc_nick_hash_color ((nickname2) ? nickname2 : nickname);
+    if (nickname2)
+        free (nickname2);
     
     snprintf (color_name, sizeof (color_name),
               "chat_nick_color%02d", color + 1);
@@ -114,13 +174,36 @@ irc_nick_find_color (const char *nickname)
     return weechat_color (color_name);
 }
 
+/*
+ * irc_nick_find_color_name: find a color name for a nick
+ *                           (according to nick letters)
+ */
+
+const char *
+irc_nick_find_color_name (const char *nickname)
+{
+    int color;
+    char *nickname2, color_name[128];
+    
+    nickname2 = irc_nick_strdup_for_color (nickname);
+    color = irc_nick_hash_color ((nickname2) ? nickname2 : nickname);
+    if (nickname2)
+        free (nickname2);
+    
+    snprintf (color_name, sizeof (color_name),
+              "weechat.color.chat_nick_color%02d", color + 1);
+    
+    return weechat_config_color (weechat_config_get (color_name));
+}
+
 /*
  * irc_nick_get_gui_infos: get GUI infos for a nick (sort_index, prefix,
  *                         prefix color)
  */
 
 void
-irc_nick_get_gui_infos (struct t_irc_nick *nick,
+irc_nick_get_gui_infos (struct t_irc_server *server,
+                        struct t_irc_nick *nick,
                         char *prefix, int *prefix_color,
                         struct t_gui_buffer *buffer,
                         struct t_gui_nick_group **group)
@@ -128,7 +211,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     if (nick->flags & IRC_NICK_CHANOWNER)
     {
         if (prefix)
-            prefix[0] = '~';
+            prefix[0] = irc_mode_get_prefix (server, 'q', '~');
         if (prefix_color)
             *prefix_color = 1;
         if (buffer && group)
@@ -138,7 +221,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_CHANADMIN)
     {
         if (prefix)
-            prefix[0] = '&';
+            prefix[0] = irc_mode_get_prefix (server, 'a', '&');
         if (prefix_color)
             *prefix_color = 1;
         if (buffer && group)
@@ -148,7 +231,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_CHANADMIN2)
     {
         if (prefix)
-            prefix[0] = '!';
+            prefix[0] = irc_mode_get_prefix (server, 'a', '!');
         if (prefix_color)
             *prefix_color = 1;
         if (buffer && group)
@@ -158,7 +241,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_OP)
     {
         if (prefix)
-            prefix[0] = '@';
+            prefix[0] = irc_mode_get_prefix (server, 'o', '@');
         if (prefix_color)
             *prefix_color = 1;
         if (buffer && group)
@@ -168,7 +251,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_HALFOP)
     {
         if (prefix)
-            prefix[0] = '%';
+            prefix[0] = irc_mode_get_prefix (server, 'h', '%');
         if (prefix_color)
             *prefix_color = 2;
         if (buffer && group)
@@ -178,7 +261,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_VOICE)
     {
         if (prefix)
-            prefix[0] = '+';
+            prefix[0] = irc_mode_get_prefix (server, 'v', '+');
         if (prefix_color)
             *prefix_color = 3;
         if (buffer && group)
@@ -188,7 +271,7 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     else if (nick->flags & IRC_NICK_CHANUSER)
     {
         if (prefix)
-            prefix[0] = '-';
+            prefix[0] = irc_mode_get_prefix (server, 'u', '-');
         if (prefix_color)
             *prefix_color = 4;
         if (buffer && group)
@@ -207,6 +290,28 @@ irc_nick_get_gui_infos (struct t_irc_nick *nick,
     }
 }
 
+/*
+ * irc_nick_get_prefix_color_name: return name of color with a prefix number
+ */
+
+const char *
+irc_nick_get_prefix_color_name (int prefix_color)
+{
+    static char *color_for_prefix[] = {
+        "chat",
+        "irc.color.nick_prefix_op",
+        "irc.color.nick_prefix_halfop",
+        "irc.color.nick_prefix_voice",
+        "irc.color.nick_prefix_user",
+    };
+    
+    if ((prefix_color >= 0) && (prefix_color <= 4))
+        return color_for_prefix[prefix_color];
+    
+    /* no color by default (should not happen) */
+    return color_for_prefix[0];
+}
+
 /*
  * irc_nick_new: allocate a new nick for a channel and add it to the nick list
  */
@@ -218,7 +323,7 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
               int is_chanuser, int is_away)
 {
     struct t_irc_nick *new_nick, *ptr_nick;
-    char prefix[2], str_prefix_color[64];
+    char prefix[2];
     int prefix_color;
     struct t_gui_nick_group *ptr_group;
     
@@ -227,7 +332,7 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
     if (ptr_nick)
     {
         /* remove old nick from nicklist */
-        irc_nick_get_gui_infos (ptr_nick, prefix,
+        irc_nick_get_gui_infos (server, ptr_nick, prefix,
                                 &prefix_color, channel->buffer, &ptr_group);
         weechat_nicklist_remove_nick (channel->buffer,
                                       weechat_nicklist_search_nick (channel->buffer,
@@ -247,16 +352,15 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
         /* add new nick in nicklist */
         prefix[0] = ' ';
         prefix[1] = '\0';
-        irc_nick_get_gui_infos (ptr_nick, prefix,
+        irc_nick_get_gui_infos (server, ptr_nick, prefix,
                                 &prefix_color, channel->buffer, &ptr_group);
-        snprintf (str_prefix_color, sizeof (str_prefix_color),
-                  "weechat.color.nicklist_prefix%d",
-                  prefix_color);
         weechat_nicklist_add_nick (channel->buffer, ptr_group,
                                    ptr_nick->name,
                                    (is_away) ?
                                    "weechat.color.nicklist_away" : "bar_fg",
-                                   prefix, str_prefix_color, 1);
+                                   prefix,
+                                   irc_nick_get_prefix_color_name (prefix_color),
+                                   1);
         
         return ptr_nick;
     }
@@ -298,16 +402,15 @@ irc_nick_new (struct t_irc_server *server, struct t_irc_channel *channel,
     /* add nick to buffer nicklist */
     prefix[0] = ' ';
     prefix[1] = '\0';
-    irc_nick_get_gui_infos (new_nick, prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, new_nick, prefix, &prefix_color,
                             channel->buffer, &ptr_group);
-    snprintf (str_prefix_color, sizeof (str_prefix_color),
-              "weechat.color.nicklist_prefix%d",
-              prefix_color);
     weechat_nicklist_add_nick (channel->buffer, ptr_group,
                                new_nick->name,
                                (is_away) ?
                                "weechat.color.nicklist_away" : "bar_fg",
-                               prefix, str_prefix_color, 1);
+                               prefix,
+                               irc_nick_get_prefix_color_name (prefix_color),
+                               1);
     
     /* all is ok, return address of new nick */
     return new_nick;
@@ -323,10 +426,10 @@ irc_nick_change (struct t_irc_server *server, struct t_irc_channel *channel,
 {
     int nick_is_me, prefix_color;
     struct t_gui_nick_group *ptr_group;
-    char prefix[2], str_prefix_color[64];
+    char prefix[2];
     
     /* remove nick from nicklist */
-    irc_nick_get_gui_infos (nick, prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, nick, prefix, &prefix_color,
                             channel->buffer, &ptr_group);
     weechat_nicklist_remove_nick (channel->buffer,
                                   weechat_nicklist_search_nick (channel->buffer,
@@ -350,16 +453,15 @@ irc_nick_change (struct t_irc_server *server, struct t_irc_channel *channel,
     /* add nick in nicklist */
     prefix[0] = ' ';
     prefix[1] = '\0';
-    irc_nick_get_gui_infos (nick, prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, nick, prefix, &prefix_color,
                             channel->buffer, &ptr_group);
-    snprintf (str_prefix_color, sizeof (str_prefix_color),
-              "weechat.color.nicklist_prefix%d",
-              prefix_color);
     weechat_nicklist_add_nick (channel->buffer, ptr_group,
                                nick->name,
                                (nick->flags & IRC_NICK_AWAY) ?
                                "weechat.color.nicklist_away" : "bar_fg",
-                               prefix, str_prefix_color, 1);
+                               prefix,
+                               irc_nick_get_prefix_color_name (prefix_color),
+                               1);
 }
 
 /*
@@ -370,12 +472,12 @@ void
 irc_nick_set (struct t_irc_server *server, struct t_irc_channel *channel,
               struct t_irc_nick *nick, int set, int flag)
 {
-    char prefix[2], str_prefix_color[64];
+    char prefix[2];
     int prefix_color;
     struct t_gui_nick_group *ptr_group;
     
     /* remove nick from nicklist */
-    irc_nick_get_gui_infos (nick, prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, nick, prefix, &prefix_color,
                             channel->buffer, &ptr_group);
     weechat_nicklist_remove_nick (channel->buffer,
                                   weechat_nicklist_search_nick (channel->buffer,
@@ -388,16 +490,15 @@ irc_nick_set (struct t_irc_server *server, struct t_irc_channel *channel,
     /* add nick in nicklist */
     prefix[0] = ' ';
     prefix[1] = '\0';
-    irc_nick_get_gui_infos (nick, prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, nick, prefix, &prefix_color,
                             channel->buffer, &ptr_group);
-    snprintf (str_prefix_color, sizeof (str_prefix_color),
-              "weechat.color.nicklist_prefix%d",
-              prefix_color);
     weechat_nicklist_add_nick (channel->buffer, ptr_group,
                                nick->name,
                                (nick->flags & IRC_NICK_AWAY) ?
                                "weechat.color.nicklist_away" : "bar_fg",
-                               prefix, str_prefix_color, 1);
+                               prefix,
+                               irc_nick_get_prefix_color_name (prefix_color),
+                               1);
     
     if (strcmp (nick->name, server->nick) == 0)
         weechat_bar_item_update ("input_prompt");
@@ -408,7 +509,8 @@ irc_nick_set (struct t_irc_server *server, struct t_irc_channel *channel,
  */
 
 void
-irc_nick_free (struct t_irc_channel *channel, struct t_irc_nick *nick)
+irc_nick_free (struct t_irc_server *server, struct t_irc_channel *channel,
+               struct t_irc_nick *nick)
 {
     struct t_irc_nick *new_nicks;
     char prefix;
@@ -419,7 +521,7 @@ irc_nick_free (struct t_irc_channel *channel, struct t_irc_nick *nick)
         return;
     
     /* remove nick from nicklist */
-    irc_nick_get_gui_infos (nick, &prefix, &prefix_color,
+    irc_nick_get_gui_infos (server, nick, &prefix, &prefix_color,
                             channel->buffer, &ptr_group);
     weechat_nicklist_remove_nick (channel->buffer,
                                   weechat_nicklist_search_nick (channel->buffer,
@@ -459,7 +561,7 @@ irc_nick_free (struct t_irc_channel *channel, struct t_irc_nick *nick)
  */
 
 void
-irc_nick_free_all (struct t_irc_channel *channel)
+irc_nick_free_all (struct t_irc_server *server, struct t_irc_channel *channel)
 {
     if (!channel)
         return;
@@ -467,7 +569,7 @@ irc_nick_free_all (struct t_irc_channel *channel)
     /* remove all nicks for the channel */
     while (channel->nicks)
     {
-        irc_nick_free (channel, channel->nicks);
+        irc_nick_free (server, channel, channel->nicks);
     }
     
     /* sould be zero, but prevent any bug :D */
@@ -516,10 +618,7 @@ irc_nick_count (struct t_irc_channel *channel, int *total, int *count_op,
          ptr_nick = ptr_nick->next_nick)
     {
         (*total)++;
-        if ((ptr_nick->flags & IRC_NICK_CHANOWNER) ||
-            (ptr_nick->flags & IRC_NICK_CHANADMIN) ||
-            (ptr_nick->flags & IRC_NICK_CHANADMIN2) ||
-            (ptr_nick->flags & IRC_NICK_OP))
+        if (IRC_NICK_IS_OP(ptr_nick))
             (*count_op)++;
         else
         {
@@ -562,11 +661,12 @@ irc_nick_set_away (struct t_irc_server *server, struct t_irc_channel *channel,
  */
 
 char *
-irc_nick_as_prefix (struct t_irc_nick *nick, const char *nickname,
-                    const char *force_color)
+irc_nick_as_prefix (struct t_irc_server *server, struct t_irc_nick *nick,
+                    const char *nickname, const char *force_color)
 {
     static char result[256];
-    char prefix[2], str_prefix_color[64];
+    char prefix[2];
+    const char *str_prefix_color;
     int prefix_color;
 
     prefix[0] = '\0';
@@ -575,26 +675,24 @@ irc_nick_as_prefix (struct t_irc_nick *nick, const char *nickname,
     {
         if (nick)
         {
-            irc_nick_get_gui_infos (nick, &prefix[0], &prefix_color, NULL, NULL);
+            irc_nick_get_gui_infos (server, nick, &prefix[0], &prefix_color,
+                                    NULL, NULL);
             if ((prefix[0] == ' ')
                 && !weechat_config_boolean (weechat_config_get ("weechat.look.nickmode_empty")))
                 prefix[0] = '\0';
-            snprintf (str_prefix_color, sizeof (str_prefix_color),
-                      "weechat.color.nicklist_prefix%d",
-                      prefix_color);
+            str_prefix_color = weechat_color (weechat_config_string (weechat_config_get (irc_nick_get_prefix_color_name (prefix_color))));
         }
         else
         {
             prefix[0] = (weechat_config_boolean (weechat_config_get ("weechat.look.nickmode_empty"))) ?
                 ' ' : '\0';
-            snprintf (str_prefix_color, sizeof (str_prefix_color),
-                      "weechat.color.chat");
+            str_prefix_color = IRC_COLOR_CHAT;
         }
     }
     else
     {
         prefix[0] = '\0';
-        snprintf (str_prefix_color, sizeof (str_prefix_color), "chat");
+        str_prefix_color = IRC_COLOR_CHAT;
     }
     
     snprintf (result, sizeof (result), "%s%s%s%s%s%s%s%s\t",
@@ -604,7 +702,7 @@ irc_nick_as_prefix (struct t_irc_nick *nick, const char *nickname,
               (weechat_config_string (irc_config_look_nick_prefix)
                && weechat_config_string (irc_config_look_nick_prefix)[0]) ?
               weechat_config_string (irc_config_look_nick_prefix) : "",
-              weechat_color(weechat_config_string(weechat_config_get(str_prefix_color))),
+              str_prefix_color,
               prefix,
               (force_color) ? force_color : ((nick) ? nick->color : IRC_COLOR_CHAT_NICK),
               (nick) ? nick->name : nickname,
