@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #ifndef __WEECHAT_IRC_SERVER_H
 #define __WEECHAT_IRC_SERVER_H 1
 
@@ -82,10 +82,8 @@ enum t_irc_server_option
       weechat_config_string(irc_config_server_default[__index])               \
       : weechat_config_string_default(irc_config_server_default[__index])))
 
-#define IRC_SERVER_DEFAULT_PORT          6667
-#define IRC_SERVER_DEFAULT_PREFIXES_LIST "@%+~&!-"
-#define IRC_SERVER_DEFAULT_NICKS         "weechat1,weechat2,weechat3,"  \
-    "weechat4,weechat5"
+#define IRC_SERVER_DEFAULT_PORT  6667
+#define IRC_SERVER_DEFAULT_NICKS "weechat1,weechat2,weechat3,weechat4,weechat5"
 
 #define IRC_SERVER_OUTQUEUE_PRIO_HIGH 1
 #define IRC_SERVER_OUTQUEUE_PRIO_LOW  2
@@ -137,7 +135,9 @@ struct t_irc_server
                                     /* when (re-)connecting to server        */
     char *nick;                     /* current nickname                      */
     char *nick_modes;               /* nick modes                            */
+    char *isupport;                 /* copy of message 005 (ISUPPORT)        */
     char *prefix;                   /* nick prefix allowed (from msg 005)    */
+    int reconnect_delay;            /* current reconnect delay (growing)     */
     time_t reconnect_start;         /* this time + delay = reconnect time    */
     time_t command_time;            /* this time + command_delay = time to   */
                                     /* autojoin channels                     */
@@ -149,6 +149,7 @@ struct t_irc_server
     int lag;                        /* lag (in milliseconds)                 */
     struct timeval lag_check_time;  /* last time lag was checked (ping sent) */
     time_t lag_next_check;          /* time for next check                   */
+    time_t lag_last_refresh;        /* last refresh of lag item              */
     regex_t *cmd_list_regexp;       /* compiled Regular Expression for /list */
     time_t last_user_message;       /* time of last user message (anti flood)*/
     struct t_irc_outqueue *outqueue[2];      /* queue for outgoing messages  */
@@ -189,6 +190,8 @@ extern void irc_server_set_addresses (struct t_irc_server *server,
 extern void irc_server_set_nicks (struct t_irc_server *server, const char *nicks);
 extern void irc_server_set_nick (struct t_irc_server *server, const char *nick);
 extern int irc_server_get_nick_index (struct t_irc_server *server);
+extern const char *irc_server_get_isupport_value (struct t_irc_server *server,
+                                                  const char *feature);
 extern struct t_irc_server *irc_server_alloc (const char *name);
 extern int irc_server_alloc_with_url (const char *irc_url);
 extern void irc_server_apply_command_line_options (struct t_irc_server *server,
@@ -233,4 +236,4 @@ extern int irc_server_add_to_infolist (struct t_infolist *infolist,
                                        struct t_irc_server *server);
 extern void irc_server_print_log ();
 
-#endif /* irc-server.h */
+#endif /* __WEECHAT_IRC_SERVER_H */
