@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc-upgrade.c: save/restore IRC plugin data when upgrading WeeChat
  */
 
-
 #include <stdio.h>
 #include <string.h>
 
@@ -253,9 +253,13 @@ irc_upgrade_read_cb (void *data,
                     str = weechat_infolist_string (infolist, "nick_modes");
                     if (str)
                         irc_upgrade_current_server->nick_modes = strdup (str);
+                    str = weechat_infolist_string (infolist, "isupport");
+                    if (str)
+                        irc_upgrade_current_server->isupport = strdup (str);
                     str = weechat_infolist_string (infolist, "prefix");
                     if (str)
                         irc_upgrade_current_server->prefix = strdup (str);
+                    irc_upgrade_current_server->reconnect_delay = weechat_infolist_integer (infolist, "reconnect_delay");
                     irc_upgrade_current_server->reconnect_start = weechat_infolist_time (infolist, "reconnect_start");
                     irc_upgrade_current_server->command_time = weechat_infolist_time (infolist, "command_time");
                     irc_upgrade_current_server->reconnect_join = weechat_infolist_integer (infolist, "reconnect_join");
@@ -270,6 +274,7 @@ irc_upgrade_read_cb (void *data,
                     if (buf)
                         memcpy (&(irc_upgrade_current_server->lag_check_time), buf, size);
                     irc_upgrade_current_server->lag_next_check = weechat_infolist_time (infolist, "lag_next_check");
+                    irc_upgrade_current_server->lag_last_refresh = weechat_infolist_time (infolist, "lag_last_refresh");
                     irc_upgrade_current_server->last_user_message = weechat_infolist_time (infolist, "last_user_message");
                 }
                 break;
@@ -296,6 +301,7 @@ irc_upgrade_read_cb (void *data,
                         str = weechat_infolist_string (infolist, "away_message");
                         if (str)
                             irc_upgrade_current_channel->away_message = strdup (str);
+                        irc_upgrade_current_channel->has_quit_server = weechat_infolist_integer (infolist, "has_quit_server");
                         irc_upgrade_current_channel->cycle = weechat_infolist_integer (infolist, "cycle");
                         irc_upgrade_current_channel->display_creation_date = weechat_infolist_integer (infolist, "display_creation_date");
                         irc_upgrade_current_channel->nick_completion_reset = weechat_infolist_integer (infolist, "nick_completion_reset");
