@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * irc.c: IRC (Internet Relay Chat) plugin for WeeChat
  */
 
-
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -44,7 +44,7 @@
 
 WEECHAT_PLUGIN_NAME(IRC_PLUGIN_NAME);
 WEECHAT_PLUGIN_DESCRIPTION("IRC (Internet Relay Chat) plugin for WeeChat");
-WEECHAT_PLUGIN_AUTHOR("FlashCode <flashcode@flashtux.org>");
+WEECHAT_PLUGIN_AUTHOR("Sebastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
 
@@ -125,14 +125,14 @@ irc_signal_upgrade_cb (void *data, const char *signal, const char *type_data,
              * after restart
              */
             ptr_server->index_current_address = 0;
-            ptr_server->reconnect_start = time (NULL) -
-                IRC_SERVER_OPTION_INTEGER(ptr_server, IRC_SERVER_OPTION_AUTORECONNECT_DELAY) - 1;
+            ptr_server->reconnect_delay = IRC_SERVER_OPTION_INTEGER(ptr_server, IRC_SERVER_OPTION_AUTORECONNECT_DELAY);
+            ptr_server->reconnect_start = time (NULL) - ptr_server->reconnect_delay - 1;
         }
     }
     if (disconnected > 0)
     {
         weechat_printf (NULL,
-                        /* TRANSLATORS: %s after %d is "server" or "servers" */
+                        /* TRANSLATORS: "%s" after "%d" is "server" or "servers" */
                         _("%s%s: disconnected from %d %s (SSL connection "
                           "not supported with upgrade)"),
                         weechat_prefix ("error"), IRC_PLUGIN_NAME,
