@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * logger.c: logger plugin for WeeChat: save buffer lines to disk files
  */
 
-
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE 1
 #endif
@@ -47,7 +47,7 @@
 
 WEECHAT_PLUGIN_NAME(LOGGER_PLUGIN_NAME);
 WEECHAT_PLUGIN_DESCRIPTION("Logger plugin for WeeChat");
-WEECHAT_PLUGIN_AUTHOR("FlashCode <flashcode@flashtux.org>");
+WEECHAT_PLUGIN_AUTHOR("Sebastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
 
@@ -82,8 +82,7 @@ logger_get_file_path ()
         goto end;
     
     /* replace "~" with user home */
-    file_path = weechat_string_replace (weechat_config_string (logger_config_file_path),
-                                        "~", getenv ("HOME"));
+    file_path = weechat_string_expand_home (weechat_config_string (logger_config_file_path));
     if (!file_path)
         goto end;
     
@@ -1126,6 +1125,11 @@ logger_line_log_level (int tags_count, const char **tags)
     
     for (i = 0; i < tags_count; i++)
     {
+        /* log disabled on line? return -1 */
+        if (strcmp (tags[i], "no_log") == 0)
+            return -1;
+        
+        /* log level for line? return it */
         if (strncmp (tags[i], "log", 3) == 0)
         {
             if (isdigit (tags[i][3]))
@@ -1135,7 +1139,8 @@ logger_line_log_level (int tags_count, const char **tags)
         }
     }
     
-    return 9;
+    /* return default log level for line */
+    return LOGGER_LEVEL_DEFAULT;
 }
 
 /*
@@ -1159,27 +1164,29 @@ logger_print_cb (void *data, struct t_gui_buffer *buffer, time_t date,
     (void) highlight;
     
     line_log_level = logger_line_log_level (tags_count, tags);
-    
-    ptr_logger_buffer = logger_buffer_search_buffer (buffer);
-    if (ptr_logger_buffer
-        && ptr_logger_buffer->log_enabled
-        && (date > 0)
-        && (line_log_level <= ptr_logger_buffer->log_level))
+    if (line_log_level >= 0)
     {
-        date_tmp = localtime (&date);
-        buf_time[0] = '\0';
-        if (date_tmp)
+        ptr_logger_buffer = logger_buffer_search_buffer (buffer);
+        if (ptr_logger_buffer
+            && ptr_logger_buffer->log_enabled
+            && (date > 0)
+            && (line_log_level <= ptr_logger_buffer->log_level))
         {
-            strftime (buf_time, sizeof (buf_time) - 1,
-                      weechat_config_string (logger_config_file_time_format),
-                      date_tmp);
+            date_tmp = localtime (&date);
+            buf_time[0] = '\0';
+            if (date_tmp)
+            {
+                strftime (buf_time, sizeof (buf_time) - 1,
+                          weechat_config_string (logger_config_file_time_format),
+                          date_tmp);
+            }
+            
+            logger_write_line (ptr_logger_buffer,
+                               "%s\t%s\t%s",
+                               buf_time,
+                               (prefix) ? prefix : "",
+                               message);
         }
-        
-        logger_write_line (ptr_logger_buffer,
-                           "%s\t%s\t%s",
-                           buf_time,
-                           (prefix) ? prefix : "",
-                           message);
     }
     
     return WEECHAT_RC_OK;
