@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * plugin.c: WeeChat plugins management (load/unload dynamic C libraries)
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -38,6 +38,7 @@
 
 #include "../core/weechat.h"
 #include "../core/wee-config.h"
+#include "../core/wee-hashtable.h"
 #include "../core/wee-hook.h"
 #include "../core/wee-infolist.h"
 #include "../core/wee-list.h"
@@ -234,7 +235,7 @@ plugin_find_pos (struct t_weechat_plugin *plugin)
 struct t_weechat_plugin *
 plugin_load (const char *filename)
 {
-    char *ptr_home, *full_name, *full_name2;
+    char *full_name, *full_name2;
     void *handle;
     char *name, *api_version, *author, *description, *version;
     char *license, *charset;
@@ -260,9 +261,7 @@ plugin_load (const char *filename)
     if (plugin_autoload_array && !plugin_check_autoload (full_name))
         return NULL;
     
-    ptr_home = getenv ("HOME");
-    full_name2 = string_replace (full_name, "~", ptr_home);
-    
+    full_name2 = string_expand_home (full_name);
     if (full_name2)
     {
         free (full_name);
@@ -462,6 +461,7 @@ plugin_load (const char *filename)
         new_plugin->strcasestr = &string_strcasestr;
         new_plugin->string_match = &string_match;
         new_plugin->string_replace = &string_replace;
+        new_plugin->string_expand_home = &string_expand_home;
         new_plugin->string_remove_quotes = &string_remove_quotes;
         new_plugin->string_strip = &string_strip;
         new_plugin->string_has_highlight = &string_has_highlight;
@@ -521,6 +521,17 @@ plugin_load (const char *filename)
         new_plugin->list_remove_all = &weelist_remove_all;
         new_plugin->list_free = &weelist_free;
         
+        new_plugin->hashtable_new = &hashtable_new;
+        new_plugin->hashtable_set_with_size = &hashtable_set_with_size;
+        new_plugin->hashtable_set = &hashtable_set;
+        new_plugin->hashtable_get = &hashtable_get;
+        new_plugin->hashtable_map = &hashtable_map;
+        new_plugin->hashtable_get_integer = &hashtable_get_integer;
+        new_plugin->hashtable_add_to_infolist = &hashtable_add_to_infolist;
+        new_plugin->hashtable_remove = &hashtable_remove;
+        new_plugin->hashtable_remove_all = &hashtable_remove_all;
+        new_plugin->hashtable_free = &hashtable_free;
+        
         new_plugin->config_new = &config_file_new;
         new_plugin->config_new_section = &config_file_new_section;
         new_plugin->config_search_section = &config_file_search_section;
@@ -780,7 +791,7 @@ plugin_auto_load_file (void *plugin, const char *filename)
 void
 plugin_auto_load ()
 {
-    char *ptr_home, *dir_name, *plugin_path, *plugin_path2;
+    char *dir_name, *plugin_path, *plugin_path2;
     
     plugin_autoload_array = NULL;
     plugin_autoload_count = 0;
@@ -797,9 +808,7 @@ plugin_auto_load ()
     if (CONFIG_STRING(config_plugin_path)
         && CONFIG_STRING(config_plugin_path)[0])
     {
-        ptr_home = getenv ("HOME");
-        plugin_path = string_replace (CONFIG_STRING(config_plugin_path),
-                                      "~", ptr_home);
+        plugin_path = string_expand_home (CONFIG_STRING(config_plugin_path));
         plugin_path2 = string_replace ((plugin_path) ?
                                        plugin_path : CONFIG_STRING(config_plugin_path),
                                        "%h", weechat_home);
