@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * script.c: common functions used by script plugins (perl/python/..)
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -281,7 +281,7 @@ script_init (struct t_weechat_plugin *weechat_plugin,
                                  callback_completion, NULL);
         weechat_hook_infolist (string, N_("list of scripts"),
                                N_("script pointer (optional)"),
-                               N_("script name (can start or end with \"*\" as joker) (optional)"),
+                               N_("script name (can start or end with \"*\" as wildcard) (optional)"),
                                callback_infolist, NULL);
         free (string);
     }
@@ -482,19 +482,7 @@ script_search_path (struct t_weechat_plugin *weechat_plugin,
     struct stat st;
     
     if (filename[0] == '~')
-    {
-        dir_home = getenv ("HOME");
-        if (!dir_home)
-            return NULL;
-        length = strlen (dir_home) + strlen (filename + 1) + 1;
-        final_name = malloc (length);
-        if (final_name)
-        {
-            snprintf (final_name, length, "%s%s", dir_home, filename + 1);
-            return final_name;
-        }
-        return NULL;
-    }
+        return weechat_string_expand_home (filename);
     
     dir_home = weechat_info_get ("weechat_dir", "");
     if (dir_home)
@@ -1064,7 +1052,7 @@ script_display_list (struct t_weechat_plugin *weechat_plugin,
     
     weechat_printf (NULL, "");
     weechat_printf (NULL,
-                    /* TRANSLATORS: %s is language (for example "perl") */
+                    /* TRANSLATORS: "%s" is language (for example "perl") */
                     _("%s scripts loaded:"),
                     weechat_plugin->name);
     if (scripts)
@@ -1113,7 +1101,7 @@ script_display_short_list (struct t_weechat_plugin *weechat_plugin,
     
     if (scripts)
     {
-        /* TRANSLATORS: %s is language (for example "perl") */
+        /* TRANSLATORS: "%s" is language (for example "perl") */
         scripts_loaded = _("%s scripts loaded:");
         
         length = strlen (scripts_loaded) + strlen (weechat_plugin->name) + 1;
