@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * xfer-file.c: file functions for xfer plugin
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -84,9 +84,7 @@ xfer_file_find_filename (struct t_xfer *xfer)
     if (!XFER_IS_FILE(xfer->type))
         return;
     
-    dir1 = weechat_string_replace (weechat_config_string (xfer_config_file_download_path),
-                                                          "~",
-                                                          getenv ("HOME"));
+    dir1 = weechat_string_expand_home (weechat_config_string (xfer_config_file_download_path));
     if (!dir1)
         return;
     
