@@ -1,26 +1,26 @@
 /*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
  * xfer.c: file transfer and direct chat plugin for WeeChat
  */
 
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -47,7 +47,7 @@
 WEECHAT_PLUGIN_NAME(XFER_PLUGIN_NAME);
 WEECHAT_PLUGIN_DESCRIPTION("Xfer (file transfer and direct chat) plugin for "
                            "WeeChat");
-WEECHAT_PLUGIN_AUTHOR("FlashCode <flashcode@flashtux.org>");
+WEECHAT_PLUGIN_AUTHOR("Sebastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
 
@@ -134,8 +134,7 @@ xfer_create_directories ()
     weechat_dir = weechat_info_get ("weechat_dir", "");
     if (weechat_dir)
     {
-        dir1 = weechat_string_replace (weechat_config_string (xfer_config_file_download_path),
-                                       "~", getenv ("HOME"));
+        dir1 = weechat_string_expand_home (weechat_config_string (xfer_config_file_download_path));
         dir2 = weechat_string_replace (dir1, "%h", weechat_dir);
         if (dir2)
             (void) weechat_mkdir (dir2, 0700);
@@ -817,12 +816,10 @@ xfer_add_cb (void *data, const char *signal, const char *type_data,
         if (filename[0] == '/')
             filename2 = strdup (filename);
         else if (filename[0] == '~')
-            filename2 = weechat_string_replace (filename, "~", getenv ("HOME"));
+            filename2 = weechat_string_expand_home (filename);
         else
         {
-            dir1 = weechat_string_replace (weechat_config_string (xfer_config_file_upload_path),
-                                           "~",
-                                           getenv ("HOME"));
+            dir1 = weechat_string_expand_home (weechat_config_string (xfer_config_file_upload_path));
             if (!dir1)
             {
                 weechat_printf (NULL,
